# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.audio_configuration import AudioConfiguration
from bitmovin_api_sdk.models.dolby_atmos_loudness_control import DolbyAtmosLoudnessControl
from bitmovin_api_sdk.models.dolby_atmos_preprocessing import DolbyAtmosPreprocessing
import pprint
import six


class DolbyAtmosAudioConfiguration(AudioConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 bitrate=None,
                 rate=None,
                 loudness_control=None,
                 preprocessing=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, float, DolbyAtmosLoudnessControl, DolbyAtmosPreprocessing) -> None
        super(DolbyAtmosAudioConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, bitrate=bitrate, rate=rate)

        self._loudness_control = None
        self._preprocessing = None
        self.discriminator = None

        if loudness_control is not None:
            self.loudness_control = loudness_control
        if preprocessing is not None:
            self.preprocessing = preprocessing

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(DolbyAtmosAudioConfiguration, self), 'openapi_types'):
            types = getattr(super(DolbyAtmosAudioConfiguration, self), 'openapi_types')

        types.update({
            'loudness_control': 'DolbyAtmosLoudnessControl',
            'preprocessing': 'DolbyAtmosPreprocessing'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(DolbyAtmosAudioConfiguration, self), 'attribute_map'):
            attributes = getattr(super(DolbyAtmosAudioConfiguration, self), 'attribute_map')

        attributes.update({
            'loudness_control': 'loudnessControl',
            'preprocessing': 'preprocessing'
        })
        return attributes

    @property
    def loudness_control(self):
        # type: () -> DolbyAtmosLoudnessControl
        """Gets the loudness_control of this DolbyAtmosAudioConfiguration.

        Settings for loudness control (required)

        :return: The loudness_control of this DolbyAtmosAudioConfiguration.
        :rtype: DolbyAtmosLoudnessControl
        """
        return self._loudness_control

    @loudness_control.setter
    def loudness_control(self, loudness_control):
        # type: (DolbyAtmosLoudnessControl) -> None
        """Sets the loudness_control of this DolbyAtmosAudioConfiguration.

        Settings for loudness control (required)

        :param loudness_control: The loudness_control of this DolbyAtmosAudioConfiguration.
        :type: DolbyAtmosLoudnessControl
        """

        if loudness_control is not None:
            if not isinstance(loudness_control, DolbyAtmosLoudnessControl):
                raise TypeError("Invalid type for `loudness_control`, type has to be `DolbyAtmosLoudnessControl`")

        self._loudness_control = loudness_control

    @property
    def preprocessing(self):
        # type: () -> DolbyAtmosPreprocessing
        """Gets the preprocessing of this DolbyAtmosAudioConfiguration.


        :return: The preprocessing of this DolbyAtmosAudioConfiguration.
        :rtype: DolbyAtmosPreprocessing
        """
        return self._preprocessing

    @preprocessing.setter
    def preprocessing(self, preprocessing):
        # type: (DolbyAtmosPreprocessing) -> None
        """Sets the preprocessing of this DolbyAtmosAudioConfiguration.


        :param preprocessing: The preprocessing of this DolbyAtmosAudioConfiguration.
        :type: DolbyAtmosPreprocessing
        """

        if preprocessing is not None:
            if not isinstance(preprocessing, DolbyAtmosPreprocessing):
                raise TypeError("Invalid type for `preprocessing`, type has to be `DolbyAtmosPreprocessing`")

        self._preprocessing = preprocessing

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(DolbyAtmosAudioConfiguration, self), "to_dict"):
            result = super(DolbyAtmosAudioConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DolbyAtmosAudioConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.live.live_api import LiveApi
from bitmovin_api_sdk.encoding.live.encodings.encodings_api import EncodingsApi
from bitmovin_api_sdk.encoding.live.dns_mappings.dns_mappings_api import DnsMappingsApi
from bitmovin_api_sdk.encoding.live.stream_keys.stream_keys_api import StreamKeysApi
from bitmovin_api_sdk.encoding.live.standby_pools.standby_pools_api import StandbyPoolsApi



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.streams_response import StreamsResponse
from bitmovin_api_sdk.models.streams_type import StreamsType
from bitmovin_api_sdk.models.streams_video_status import StreamsVideoStatus
from bitmovin_api_sdk.streams.search.streams_response_list_query_params import StreamsResponseListQueryParams


class SearchApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SearchApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, query_params=None, **kwargs):
        # type: (StreamsResponseListQueryParams, dict) -> StreamsResponse
        """Get paginated search results of VOD and Live streams

        :param query_params: Query parameters
        :type query_params: StreamsResponseListQueryParams
        :return: List of all search results
        :rtype: StreamsResponse
        """

        return self.api_client.get(
            '/streams/search',
            query_params=query_params,
            pagination_response=True,
            type=StreamsResponse,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class LiveStandbyPoolAcquireEncoding(object):
    @poscheck_model
    def __init__(self,
                 ingest_points=None):
        # type: (list[LiveStandbyPoolEncodingIngestPoint]) -> None

        self._ingest_points = list()
        self.discriminator = None

        if ingest_points is not None:
            self.ingest_points = ingest_points

    @property
    def openapi_types(self):
        types = {
            'ingest_points': 'list[LiveStandbyPoolEncodingIngestPoint]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'ingest_points': 'ingestPoints'
        }
        return attributes

    @property
    def ingest_points(self):
        # type: () -> list[LiveStandbyPoolEncodingIngestPoint]
        """Gets the ingest_points of this LiveStandbyPoolAcquireEncoding.

        Note: This is not implemented yet and will be ignored if provided. List of ingest points to be used for the acquired encoding. The DNS hostname and RTMPs application name and streamKey will be assigned to the encoding. 

        :return: The ingest_points of this LiveStandbyPoolAcquireEncoding.
        :rtype: list[LiveStandbyPoolEncodingIngestPoint]
        """
        return self._ingest_points

    @ingest_points.setter
    def ingest_points(self, ingest_points):
        # type: (list) -> None
        """Sets the ingest_points of this LiveStandbyPoolAcquireEncoding.

        Note: This is not implemented yet and will be ignored if provided. List of ingest points to be used for the acquired encoding. The DNS hostname and RTMPs application name and streamKey will be assigned to the encoding. 

        :param ingest_points: The ingest_points of this LiveStandbyPoolAcquireEncoding.
        :type: list[LiveStandbyPoolEncodingIngestPoint]
        """

        if ingest_points is not None:
            if not isinstance(ingest_points, list):
                raise TypeError("Invalid type for `ingest_points`, type has to be `list[LiveStandbyPoolEncodingIngestPoint]`")

        self._ingest_points = ingest_points

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveStandbyPoolAcquireEncoding):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ScenePacing(Enum):
    SLOW = "SLOW"
    MEASURED = "MEASURED"
    BRISK = "BRISK"
    FRANTIC = "FRANTIC"
    UNKNOWN = "UNKNOWN"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.bitmovin_response_list import BitmovinResponseList
from bitmovin_api_sdk.models.dns_mapping_request import DnsMappingRequest
from bitmovin_api_sdk.models.dns_mapping_response import DnsMappingResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.live.encodings.dns_mappings.dns_mapping_response_list_query_params import DnsMappingResponseListQueryParams


class DnsMappingsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(DnsMappingsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, dns_mapping_request, **kwargs):
        # type: (string_types, DnsMappingRequest, dict) -> DnsMappingResponse
        """Create new DNS mapping for encoding

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param dns_mapping_request: The DNS mapping to be created
        :type dns_mapping_request: DnsMappingRequest, required
        :return:
        :rtype: DnsMappingResponse
        """

        return self.api_client.post(
            '/encoding/live/encodings/{encoding_id}/dns-mappings',
            dns_mapping_request,
            path_params={'encoding_id': encoding_id},
            type=DnsMappingResponse,
            **kwargs
        )

    def delete(self, encoding_id, id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete DNS mapping

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param id: Id of the DNS mapping
        :type id: string_types, required
        :return: Id of the DNS mapping that was deleted
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/live/encodings/{encoding_id}/dns-mappings/{id}',
            path_params={'encoding_id': encoding_id, 'id': id},
            type=BitmovinResponse,
            **kwargs
        )

    def delete_all(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponseList
        """Delete all DNS mappings for encoding

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :return: List of ids of deleted DNS mappings
        :rtype: BitmovinResponseList
        """

        return self.api_client.delete(
            '/encoding/live/encodings/{encoding_id}/dns-mappings',
            path_params={'encoding_id': encoding_id},
            type=BitmovinResponseList,
            **kwargs
        )

    def get(self, encoding_id, id, **kwargs):
        # type: (string_types, string_types, dict) -> DnsMappingResponse
        """DNS mapping details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param id: Id of the DNS mapping
        :type id: string_types, required
        :return: DNS mapping
        :rtype: DnsMappingResponse
        """

        return self.api_client.get(
            '/encoding/live/encodings/{encoding_id}/dns-mappings/{id}',
            path_params={'encoding_id': encoding_id, 'id': id},
            type=DnsMappingResponse,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, DnsMappingResponseListQueryParams, dict) -> DnsMappingResponse
        """List DNS mappings for encoding

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: DnsMappingResponseListQueryParams
        :return: List of DNS mappings
        :rtype: DnsMappingResponse
        """

        return self.api_client.get(
            '/encoding/live/encodings/{encoding_id}/dns-mappings',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=DnsMappingResponse,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.burn_in_subtitle_assa import BurnInSubtitleAssa
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.streams.burn_in_subtitles.assa.burn_in_subtitle_assa_list_query_params import BurnInSubtitleAssaListQueryParams


class AssaApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(AssaApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, stream_id, burn_in_subtitle_assa, **kwargs):
        # type: (string_types, string_types, BurnInSubtitleAssa, dict) -> BurnInSubtitleAssa
        """Burn-In ASSA Subtitle into Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param burn_in_subtitle_assa: The Burn-In ASSA Subtitle to be added
        :type burn_in_subtitle_assa: BurnInSubtitleAssa, required
        :return: Burn-in ASSA subtitle details
        :rtype: BurnInSubtitleAssa
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/burn-in-subtitles/assa',
            burn_in_subtitle_assa,
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            type=BurnInSubtitleAssa,
            **kwargs
        )

    def delete(self, encoding_id, stream_id, subtitle_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete Burn-In ASSA Subtitle from Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param subtitle_id: Id of the burn-in subtitle.
        :type subtitle_id: string_types, required
        :return: Id of the burn-in ASSA subtitle
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/burn-in-subtitles/assa/{subtitle_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id, 'subtitle_id': subtitle_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, stream_id, subtitle_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BurnInSubtitleAssa
        """Get Burn-In ASSA Subtitle Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param subtitle_id: Id of the burn-in subtitle.
        :type subtitle_id: string_types, required
        :return: Burn-in ASSA subtitle details
        :rtype: BurnInSubtitleAssa
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/burn-in-subtitles/assa/{subtitle_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id, 'subtitle_id': subtitle_id},
            type=BurnInSubtitleAssa,
            **kwargs
        )

    def list(self, encoding_id, stream_id, query_params=None, **kwargs):
        # type: (string_types, string_types, BurnInSubtitleAssaListQueryParams, dict) -> BurnInSubtitleAssa
        """List the Burn-In ASSA subtitles of a stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param query_params: Query parameters
        :type query_params: BurnInSubtitleAssaListQueryParams
        :return: List of burn-in ASSA configurations
        :rtype: BurnInSubtitleAssa
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/burn-in-subtitles/assa',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            query_params=query_params,
            pagination_response=True,
            type=BurnInSubtitleAssa,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.input_type import InputType
import pprint
import six


class LiveEncodingHeartbeatIngestPoint(object):
    @poscheck_model
    def __init__(self,
                 name=None,
                 input_id=None,
                 input_type=None,
                 is_active=None,
                 is_backup=None):
        # type: (string_types, string_types, InputType, bool, bool) -> None

        self._name = None
        self._input_id = None
        self._input_type = None
        self._is_active = None
        self._is_backup = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if input_id is not None:
            self.input_id = input_id
        if input_type is not None:
            self.input_type = input_type
        if is_active is not None:
            self.is_active = is_active
        if is_backup is not None:
            self.is_backup = is_backup

    @property
    def openapi_types(self):
        types = {
            'name': 'string_types',
            'input_id': 'string_types',
            'input_type': 'InputType',
            'is_active': 'bool',
            'is_backup': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'name': 'name',
            'input_id': 'inputId',
            'input_type': 'inputType',
            'is_active': 'isActive',
            'is_backup': 'isBackup'
        }
        return attributes

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this LiveEncodingHeartbeatIngestPoint.

        The name of the ingestPoint of the original Input resource. 

        :return: The name of this LiveEncodingHeartbeatIngestPoint.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this LiveEncodingHeartbeatIngestPoint.

        The name of the ingestPoint of the original Input resource. 

        :param name: The name of this LiveEncodingHeartbeatIngestPoint.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    @property
    def input_id(self):
        # type: () -> string_types
        """Gets the input_id of this LiveEncodingHeartbeatIngestPoint.

        Id of the original Input resource. Note that multiple input points (main and backup) can be part of a single Input resource. 

        :return: The input_id of this LiveEncodingHeartbeatIngestPoint.
        :rtype: string_types
        """
        return self._input_id

    @input_id.setter
    def input_id(self, input_id):
        # type: (string_types) -> None
        """Sets the input_id of this LiveEncodingHeartbeatIngestPoint.

        Id of the original Input resource. Note that multiple input points (main and backup) can be part of a single Input resource. 

        :param input_id: The input_id of this LiveEncodingHeartbeatIngestPoint.
        :type: string_types
        """

        if input_id is not None:
            if not isinstance(input_id, string_types):
                raise TypeError("Invalid type for `input_id`, type has to be `string_types`")

        self._input_id = input_id

    @property
    def input_type(self):
        # type: () -> InputType
        """Gets the input_type of this LiveEncodingHeartbeatIngestPoint.


        :return: The input_type of this LiveEncodingHeartbeatIngestPoint.
        :rtype: InputType
        """
        return self._input_type

    @input_type.setter
    def input_type(self, input_type):
        # type: (InputType) -> None
        """Sets the input_type of this LiveEncodingHeartbeatIngestPoint.


        :param input_type: The input_type of this LiveEncodingHeartbeatIngestPoint.
        :type: InputType
        """

        if input_type is not None:
            if not isinstance(input_type, InputType):
                raise TypeError("Invalid type for `input_type`, type has to be `InputType`")

        self._input_type = input_type

    @property
    def is_active(self):
        # type: () -> bool
        """Gets the is_active of this LiveEncodingHeartbeatIngestPoint.

        Indicates whether this particular input is active.

        :return: The is_active of this LiveEncodingHeartbeatIngestPoint.
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        # type: (bool) -> None
        """Sets the is_active of this LiveEncodingHeartbeatIngestPoint.

        Indicates whether this particular input is active.

        :param is_active: The is_active of this LiveEncodingHeartbeatIngestPoint.
        :type: bool
        """

        if is_active is not None:
            if not isinstance(is_active, bool):
                raise TypeError("Invalid type for `is_active`, type has to be `bool`")

        self._is_active = is_active

    @property
    def is_backup(self):
        # type: () -> bool
        """Gets the is_backup of this LiveEncodingHeartbeatIngestPoint.

        Indicates whether this particular input is a backup input.

        :return: The is_backup of this LiveEncodingHeartbeatIngestPoint.
        :rtype: bool
        """
        return self._is_backup

    @is_backup.setter
    def is_backup(self, is_backup):
        # type: (bool) -> None
        """Sets the is_backup of this LiveEncodingHeartbeatIngestPoint.

        Indicates whether this particular input is a backup input.

        :param is_backup: The is_backup of this LiveEncodingHeartbeatIngestPoint.
        :type: bool
        """

        if is_backup is not None:
            if not isinstance(is_backup, bool):
                raise TypeError("Invalid type for `is_backup`, type has to be `bool`")

        self._is_backup = is_backup

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveEncodingHeartbeatIngestPoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class OpusChannelLayout(Enum):
    NONE = "NONE"
    MONO = "MONO"
    CL_STEREO = "STEREO"
    CL_SURROUND = "SURROUND"
    CL_QUAD = "QUAD"
    CL_4_1 = "4.1"
    CL_5_0_BACK = "5.0_BACK"
    XCL_5_1_BACK = "5.1_BACK"
    CL_6_1 = "6.1"
    CL_7_1 = "7.1"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.muxing import Muxing
from bitmovin_api_sdk.models.stream_conditions_mode import StreamConditionsMode
from bitmovin_api_sdk.models.ts_muxing_configuration import TsMuxingConfiguration
import pprint
import six


class TsMuxing(Muxing):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 streams=None,
                 outputs=None,
                 avg_bitrate=None,
                 min_bitrate=None,
                 max_bitrate=None,
                 ignored_by=None,
                 stream_conditions_mode=None,
                 segment_length=None,
                 minimum_segment_length=None,
                 segment_naming=None,
                 segment_naming_template=None,
                 start_offset=None,
                 segments_muxed=None,
                 configuration=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[MuxingStream], list[EncodingOutput], int, int, int, list[Ignoring], StreamConditionsMode, float, float, string_types, string_types, int, int, TsMuxingConfiguration) -> None
        super(TsMuxing, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, streams=streams, outputs=outputs, avg_bitrate=avg_bitrate, min_bitrate=min_bitrate, max_bitrate=max_bitrate, ignored_by=ignored_by, stream_conditions_mode=stream_conditions_mode)

        self._segment_length = None
        self._minimum_segment_length = None
        self._segment_naming = None
        self._segment_naming_template = None
        self._start_offset = None
        self._segments_muxed = None
        self._configuration = None
        self.discriminator = None

        if segment_length is not None:
            self.segment_length = segment_length
        if minimum_segment_length is not None:
            self.minimum_segment_length = minimum_segment_length
        if segment_naming is not None:
            self.segment_naming = segment_naming
        if segment_naming_template is not None:
            self.segment_naming_template = segment_naming_template
        if start_offset is not None:
            self.start_offset = start_offset
        if segments_muxed is not None:
            self.segments_muxed = segments_muxed
        if configuration is not None:
            self.configuration = configuration

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(TsMuxing, self), 'openapi_types'):
            types = getattr(super(TsMuxing, self), 'openapi_types')

        types.update({
            'segment_length': 'float',
            'minimum_segment_length': 'float',
            'segment_naming': 'string_types',
            'segment_naming_template': 'string_types',
            'start_offset': 'int',
            'segments_muxed': 'int',
            'configuration': 'TsMuxingConfiguration'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(TsMuxing, self), 'attribute_map'):
            attributes = getattr(super(TsMuxing, self), 'attribute_map')

        attributes.update({
            'segment_length': 'segmentLength',
            'minimum_segment_length': 'minimumSegmentLength',
            'segment_naming': 'segmentNaming',
            'segment_naming_template': 'segmentNamingTemplate',
            'start_offset': 'startOffset',
            'segments_muxed': 'segmentsMuxed',
            'configuration': 'configuration'
        })
        return attributes

    @property
    def segment_length(self):
        # type: () -> float
        """Gets the segment_length of this TsMuxing.

        Length of the fragments in seconds

        :return: The segment_length of this TsMuxing.
        :rtype: float
        """
        return self._segment_length

    @segment_length.setter
    def segment_length(self, segment_length):
        # type: (float) -> None
        """Sets the segment_length of this TsMuxing.

        Length of the fragments in seconds

        :param segment_length: The segment_length of this TsMuxing.
        :type: float
        """

        if segment_length is not None:
            if not isinstance(segment_length, (float, int)):
                raise TypeError("Invalid type for `segment_length`, type has to be `float`")

        self._segment_length = segment_length

    @property
    def minimum_segment_length(self):
        # type: () -> float
        """Gets the minimum_segment_length of this TsMuxing.

        Prevents creation of very short segments (in seconds). If the last segment is shorter than minimumSegmentLength or there is a custom keyframe too close to a segment boundary, short segments will be omitted by removing segment boundaries, resulting in a segment of a size up to segmentLength + minimumSegmentLength.

        :return: The minimum_segment_length of this TsMuxing.
        :rtype: float
        """
        return self._minimum_segment_length

    @minimum_segment_length.setter
    def minimum_segment_length(self, minimum_segment_length):
        # type: (float) -> None
        """Sets the minimum_segment_length of this TsMuxing.

        Prevents creation of very short segments (in seconds). If the last segment is shorter than minimumSegmentLength or there is a custom keyframe too close to a segment boundary, short segments will be omitted by removing segment boundaries, resulting in a segment of a size up to segmentLength + minimumSegmentLength.

        :param minimum_segment_length: The minimum_segment_length of this TsMuxing.
        :type: float
        """

        if minimum_segment_length is not None:
            if not isinstance(minimum_segment_length, (float, int)):
                raise TypeError("Invalid type for `minimum_segment_length`, type has to be `float`")

        self._minimum_segment_length = minimum_segment_length

    @property
    def segment_naming(self):
        # type: () -> string_types
        """Gets the segment_naming of this TsMuxing.

        Segment naming policy

        :return: The segment_naming of this TsMuxing.
        :rtype: string_types
        """
        return self._segment_naming

    @segment_naming.setter
    def segment_naming(self, segment_naming):
        # type: (string_types) -> None
        """Sets the segment_naming of this TsMuxing.

        Segment naming policy

        :param segment_naming: The segment_naming of this TsMuxing.
        :type: string_types
        """

        if segment_naming is not None:
            if not isinstance(segment_naming, string_types):
                raise TypeError("Invalid type for `segment_naming`, type has to be `string_types`")

        self._segment_naming = segment_naming

    @property
    def segment_naming_template(self):
        # type: () -> string_types
        """Gets the segment_naming_template of this TsMuxing.

        Segment naming policy containing one or both of the following placeholders: - '{rand_chars:x}', which will be replaced by a random alphanumeric string of length x (default 32)   on each (re)start of the encoding. The resulting string will be copied to the segmentNaming property.   Intended to avoid re-use of segment names after restarting a live encoding. - '{segment_rand_chars:x}', which will be replaced by a random alphanumeric string of length x (default 32)   for each different segment. This is intended to avoid guessing segment URLs by replacing segment numbers.  If segmentNamingTemplate is set, segmentNaming must not be set. 

        :return: The segment_naming_template of this TsMuxing.
        :rtype: string_types
        """
        return self._segment_naming_template

    @segment_naming_template.setter
    def segment_naming_template(self, segment_naming_template):
        # type: (string_types) -> None
        """Sets the segment_naming_template of this TsMuxing.

        Segment naming policy containing one or both of the following placeholders: - '{rand_chars:x}', which will be replaced by a random alphanumeric string of length x (default 32)   on each (re)start of the encoding. The resulting string will be copied to the segmentNaming property.   Intended to avoid re-use of segment names after restarting a live encoding. - '{segment_rand_chars:x}', which will be replaced by a random alphanumeric string of length x (default 32)   for each different segment. This is intended to avoid guessing segment URLs by replacing segment numbers.  If segmentNamingTemplate is set, segmentNaming must not be set. 

        :param segment_naming_template: The segment_naming_template of this TsMuxing.
        :type: string_types
        """

        if segment_naming_template is not None:
            if not isinstance(segment_naming_template, string_types):
                raise TypeError("Invalid type for `segment_naming_template`, type has to be `string_types`")

        self._segment_naming_template = segment_naming_template

    @property
    def start_offset(self):
        # type: () -> int
        """Gets the start_offset of this TsMuxing.

        Offset of MPEG-TS timestamps in seconds. E.g., first packet will start with PTS 900,000 for a 10 seconds offset (90,000 MPEG-TS timescale).

        :return: The start_offset of this TsMuxing.
        :rtype: int
        """
        return self._start_offset

    @start_offset.setter
    def start_offset(self, start_offset):
        # type: (int) -> None
        """Sets the start_offset of this TsMuxing.

        Offset of MPEG-TS timestamps in seconds. E.g., first packet will start with PTS 900,000 for a 10 seconds offset (90,000 MPEG-TS timescale).

        :param start_offset: The start_offset of this TsMuxing.
        :type: int
        """

        if start_offset is not None:
            if not isinstance(start_offset, int):
                raise TypeError("Invalid type for `start_offset`, type has to be `int`")

        self._start_offset = start_offset

    @property
    def segments_muxed(self):
        # type: () -> int
        """Gets the segments_muxed of this TsMuxing.

        Number of segments which have been encoded

        :return: The segments_muxed of this TsMuxing.
        :rtype: int
        """
        return self._segments_muxed

    @segments_muxed.setter
    def segments_muxed(self, segments_muxed):
        # type: (int) -> None
        """Sets the segments_muxed of this TsMuxing.

        Number of segments which have been encoded

        :param segments_muxed: The segments_muxed of this TsMuxing.
        :type: int
        """

        if segments_muxed is not None:
            if not isinstance(segments_muxed, int):
                raise TypeError("Invalid type for `segments_muxed`, type has to be `int`")

        self._segments_muxed = segments_muxed

    @property
    def configuration(self):
        # type: () -> TsMuxingConfiguration
        """Gets the configuration of this TsMuxing.

        Advanced Configuration of the MPEG Transport Stream Parameters

        :return: The configuration of this TsMuxing.
        :rtype: TsMuxingConfiguration
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        # type: (TsMuxingConfiguration) -> None
        """Sets the configuration of this TsMuxing.

        Advanced Configuration of the MPEG Transport Stream Parameters

        :param configuration: The configuration of this TsMuxing.
        :type: TsMuxingConfiguration
        """

        if configuration is not None:
            if not isinstance(configuration, TsMuxingConfiguration):
                raise TypeError("Invalid type for `configuration`, type has to be `TsMuxingConfiguration`")

        self._configuration = configuration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(TsMuxing, self), "to_dict"):
            result = super(TsMuxing, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsMuxing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.esam_direction import EsamDirection
import pprint
import six


class EsamCondition(object):
    @poscheck_model
    def __init__(self,
                 offset=None,
                 direction=None):
        # type: (string_types, EsamDirection) -> None

        self._offset = None
        self._direction = None
        self.discriminator = None

        if offset is not None:
            self.offset = offset
        if direction is not None:
            self.direction = direction

    @property
    def openapi_types(self):
        types = {
            'offset': 'string_types',
            'direction': 'EsamDirection'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'offset': 'offset',
            'direction': 'direction'
        }
        return attributes

    @property
    def offset(self):
        # type: () -> string_types
        """Gets the offset of this EsamCondition.

        The offset from the matched signal when this condition applies in ISO 8601 duration format, accurate to milliseconds (required)

        :return: The offset of this EsamCondition.
        :rtype: string_types
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        # type: (string_types) -> None
        """Sets the offset of this EsamCondition.

        The offset from the matched signal when this condition applies in ISO 8601 duration format, accurate to milliseconds (required)

        :param offset: The offset of this EsamCondition.
        :type: string_types
        """

        if offset is not None:
            if not isinstance(offset, string_types):
                raise TypeError("Invalid type for `offset`, type has to be `string_types`")

        self._offset = offset

    @property
    def direction(self):
        # type: () -> EsamDirection
        """Gets the direction of this EsamCondition.

        Direction marker indicating the boundary type (OUT for start, IN for end) (required)

        :return: The direction of this EsamCondition.
        :rtype: EsamDirection
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        # type: (EsamDirection) -> None
        """Sets the direction of this EsamCondition.

        Direction marker indicating the boundary type (OUT for start, IN for end) (required)

        :param direction: The direction of this EsamCondition.
        :type: EsamDirection
        """

        if direction is not None:
            if not isinstance(direction, EsamDirection):
                raise TypeError("Invalid type for `direction`, type has to be `EsamDirection`")

        self._direction = direction

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EsamCondition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dolby_atmos_dynamic_range_compression import DolbyAtmosDynamicRangeCompression
import pprint
import six


class DolbyAtmosPreprocessing(object):
    @poscheck_model
    def __init__(self,
                 dynamic_range_compression=None):
        # type: (DolbyAtmosDynamicRangeCompression) -> None

        self._dynamic_range_compression = None
        self.discriminator = None

        if dynamic_range_compression is not None:
            self.dynamic_range_compression = dynamic_range_compression

    @property
    def openapi_types(self):
        types = {
            'dynamic_range_compression': 'DolbyAtmosDynamicRangeCompression'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'dynamic_range_compression': 'dynamicRangeCompression'
        }
        return attributes

    @property
    def dynamic_range_compression(self):
        # type: () -> DolbyAtmosDynamicRangeCompression
        """Gets the dynamic_range_compression of this DolbyAtmosPreprocessing.

        It indicates a gain change to be applied in the Dolby Atmos decoder in order to implement dynamic range compression.  The values typically indicate gain reductions (cut) during loud passages and gain increases (boost) during quiet passages based on desired compression characteristics. 

        :return: The dynamic_range_compression of this DolbyAtmosPreprocessing.
        :rtype: DolbyAtmosDynamicRangeCompression
        """
        return self._dynamic_range_compression

    @dynamic_range_compression.setter
    def dynamic_range_compression(self, dynamic_range_compression):
        # type: (DolbyAtmosDynamicRangeCompression) -> None
        """Sets the dynamic_range_compression of this DolbyAtmosPreprocessing.

        It indicates a gain change to be applied in the Dolby Atmos decoder in order to implement dynamic range compression.  The values typically indicate gain reductions (cut) during loud passages and gain increases (boost) during quiet passages based on desired compression characteristics. 

        :param dynamic_range_compression: The dynamic_range_compression of this DolbyAtmosPreprocessing.
        :type: DolbyAtmosDynamicRangeCompression
        """

        if dynamic_range_compression is not None:
            if not isinstance(dynamic_range_compression, DolbyAtmosDynamicRangeCompression):
                raise TypeError("Invalid type for `dynamic_range_compression`, type has to be `DolbyAtmosDynamicRangeCompression`")

        self._dynamic_range_compression = dynamic_range_compression

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DolbyAtmosPreprocessing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class LiveEncodingHeartbeatIngestStream(object):
    @poscheck_model
    def __init__(self,
                 stream_id=None,
                 media_type=None,
                 width=None,
                 height=None,
                 rate=None,
                 codec=None,
                 aspect_ratio=None,
                 bitrate=None,
                 samples_read_per_second_avg=None,
                 incoming_bitrate=None,
                 key_frame_interval_max=None,
                 key_frame_interval_avg=None,
                 last_timestamp=None,
                 last_timestamp_timescale=None,
                 number_of_audio_channels=None,
                 audio_channel_format=None,
                 last_arrival_time=None,
                 healthy=None):
        # type: (string_types, string_types, int, int, float, string_types, string_types, int, float, float, int, float, int, int, int, string_types, datetime, bool) -> None

        self._stream_id = None
        self._media_type = None
        self._width = None
        self._height = None
        self._rate = None
        self._codec = None
        self._aspect_ratio = None
        self._bitrate = None
        self._samples_read_per_second_avg = None
        self._incoming_bitrate = None
        self._key_frame_interval_max = None
        self._key_frame_interval_avg = None
        self._last_timestamp = None
        self._last_timestamp_timescale = None
        self._number_of_audio_channels = None
        self._audio_channel_format = None
        self._last_arrival_time = None
        self._healthy = None
        self.discriminator = None

        if stream_id is not None:
            self.stream_id = stream_id
        if media_type is not None:
            self.media_type = media_type
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if rate is not None:
            self.rate = rate
        if codec is not None:
            self.codec = codec
        if aspect_ratio is not None:
            self.aspect_ratio = aspect_ratio
        if bitrate is not None:
            self.bitrate = bitrate
        if samples_read_per_second_avg is not None:
            self.samples_read_per_second_avg = samples_read_per_second_avg
        if incoming_bitrate is not None:
            self.incoming_bitrate = incoming_bitrate
        if key_frame_interval_max is not None:
            self.key_frame_interval_max = key_frame_interval_max
        if key_frame_interval_avg is not None:
            self.key_frame_interval_avg = key_frame_interval_avg
        if last_timestamp is not None:
            self.last_timestamp = last_timestamp
        if last_timestamp_timescale is not None:
            self.last_timestamp_timescale = last_timestamp_timescale
        if number_of_audio_channels is not None:
            self.number_of_audio_channels = number_of_audio_channels
        if audio_channel_format is not None:
            self.audio_channel_format = audio_channel_format
        if last_arrival_time is not None:
            self.last_arrival_time = last_arrival_time
        if healthy is not None:
            self.healthy = healthy

    @property
    def openapi_types(self):
        types = {
            'stream_id': 'string_types',
            'media_type': 'string_types',
            'width': 'int',
            'height': 'int',
            'rate': 'float',
            'codec': 'string_types',
            'aspect_ratio': 'string_types',
            'bitrate': 'int',
            'samples_read_per_second_avg': 'float',
            'incoming_bitrate': 'float',
            'key_frame_interval_max': 'int',
            'key_frame_interval_avg': 'float',
            'last_timestamp': 'int',
            'last_timestamp_timescale': 'int',
            'number_of_audio_channels': 'int',
            'audio_channel_format': 'string_types',
            'last_arrival_time': 'datetime',
            'healthy': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'stream_id': 'streamId',
            'media_type': 'mediaType',
            'width': 'width',
            'height': 'height',
            'rate': 'rate',
            'codec': 'codec',
            'aspect_ratio': 'aspectRatio',
            'bitrate': 'bitrate',
            'samples_read_per_second_avg': 'samplesReadPerSecondAvg',
            'incoming_bitrate': 'incomingBitrate',
            'key_frame_interval_max': 'keyFrameIntervalMax',
            'key_frame_interval_avg': 'keyFrameIntervalAvg',
            'last_timestamp': 'lastTimestamp',
            'last_timestamp_timescale': 'lastTimestampTimescale',
            'number_of_audio_channels': 'numberOfAudioChannels',
            'audio_channel_format': 'audioChannelFormat',
            'last_arrival_time': 'lastArrivalTime',
            'healthy': 'healthy'
        }
        return attributes

    @property
    def stream_id(self):
        # type: () -> string_types
        """Gets the stream_id of this LiveEncodingHeartbeatIngestStream.

        Unique identifier of the stream.

        :return: The stream_id of this LiveEncodingHeartbeatIngestStream.
        :rtype: string_types
        """
        return self._stream_id

    @stream_id.setter
    def stream_id(self, stream_id):
        # type: (string_types) -> None
        """Sets the stream_id of this LiveEncodingHeartbeatIngestStream.

        Unique identifier of the stream.

        :param stream_id: The stream_id of this LiveEncodingHeartbeatIngestStream.
        :type: string_types
        """

        if stream_id is not None:
            if not isinstance(stream_id, string_types):
                raise TypeError("Invalid type for `stream_id`, type has to be `string_types`")

        self._stream_id = stream_id

    @property
    def media_type(self):
        # type: () -> string_types
        """Gets the media_type of this LiveEncodingHeartbeatIngestStream.

        Media type for the stream (e.g., \"video\" or \"audio\").

        :return: The media_type of this LiveEncodingHeartbeatIngestStream.
        :rtype: string_types
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        # type: (string_types) -> None
        """Sets the media_type of this LiveEncodingHeartbeatIngestStream.

        Media type for the stream (e.g., \"video\" or \"audio\").

        :param media_type: The media_type of this LiveEncodingHeartbeatIngestStream.
        :type: string_types
        """

        if media_type is not None:
            if not isinstance(media_type, string_types):
                raise TypeError("Invalid type for `media_type`, type has to be `string_types`")

        self._media_type = media_type

    @property
    def width(self):
        # type: () -> int
        """Gets the width of this LiveEncodingHeartbeatIngestStream.

        Width of the video stream in pixels.

        :return: The width of this LiveEncodingHeartbeatIngestStream.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        # type: (int) -> None
        """Sets the width of this LiveEncodingHeartbeatIngestStream.

        Width of the video stream in pixels.

        :param width: The width of this LiveEncodingHeartbeatIngestStream.
        :type: int
        """

        if width is not None:
            if not isinstance(width, int):
                raise TypeError("Invalid type for `width`, type has to be `int`")

        self._width = width

    @property
    def height(self):
        # type: () -> int
        """Gets the height of this LiveEncodingHeartbeatIngestStream.

        Height of the video stream in pixels.

        :return: The height of this LiveEncodingHeartbeatIngestStream.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        # type: (int) -> None
        """Sets the height of this LiveEncodingHeartbeatIngestStream.

        Height of the video stream in pixels.

        :param height: The height of this LiveEncodingHeartbeatIngestStream.
        :type: int
        """

        if height is not None:
            if not isinstance(height, int):
                raise TypeError("Invalid type for `height`, type has to be `int`")

        self._height = height

    @property
    def rate(self):
        # type: () -> float
        """Gets the rate of this LiveEncodingHeartbeatIngestStream.

        Frame rate of the video stream.

        :return: The rate of this LiveEncodingHeartbeatIngestStream.
        :rtype: float
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        # type: (float) -> None
        """Sets the rate of this LiveEncodingHeartbeatIngestStream.

        Frame rate of the video stream.

        :param rate: The rate of this LiveEncodingHeartbeatIngestStream.
        :type: float
        """

        if rate is not None:
            if not isinstance(rate, (float, int)):
                raise TypeError("Invalid type for `rate`, type has to be `float`")

        self._rate = rate

    @property
    def codec(self):
        # type: () -> string_types
        """Gets the codec of this LiveEncodingHeartbeatIngestStream.

        Codec of the stream.

        :return: The codec of this LiveEncodingHeartbeatIngestStream.
        :rtype: string_types
        """
        return self._codec

    @codec.setter
    def codec(self, codec):
        # type: (string_types) -> None
        """Sets the codec of this LiveEncodingHeartbeatIngestStream.

        Codec of the stream.

        :param codec: The codec of this LiveEncodingHeartbeatIngestStream.
        :type: string_types
        """

        if codec is not None:
            if not isinstance(codec, string_types):
                raise TypeError("Invalid type for `codec`, type has to be `string_types`")

        self._codec = codec

    @property
    def aspect_ratio(self):
        # type: () -> string_types
        """Gets the aspect_ratio of this LiveEncodingHeartbeatIngestStream.

        Aspect ratio of the video.

        :return: The aspect_ratio of this LiveEncodingHeartbeatIngestStream.
        :rtype: string_types
        """
        return self._aspect_ratio

    @aspect_ratio.setter
    def aspect_ratio(self, aspect_ratio):
        # type: (string_types) -> None
        """Sets the aspect_ratio of this LiveEncodingHeartbeatIngestStream.

        Aspect ratio of the video.

        :param aspect_ratio: The aspect_ratio of this LiveEncodingHeartbeatIngestStream.
        :type: string_types
        """

        if aspect_ratio is not None:
            if not isinstance(aspect_ratio, string_types):
                raise TypeError("Invalid type for `aspect_ratio`, type has to be `string_types`")

        self._aspect_ratio = aspect_ratio

    @property
    def bitrate(self):
        # type: () -> int
        """Gets the bitrate of this LiveEncodingHeartbeatIngestStream.

        Container format's bitrate of the stream, in bits per second.

        :return: The bitrate of this LiveEncodingHeartbeatIngestStream.
        :rtype: int
        """
        return self._bitrate

    @bitrate.setter
    def bitrate(self, bitrate):
        # type: (int) -> None
        """Sets the bitrate of this LiveEncodingHeartbeatIngestStream.

        Container format's bitrate of the stream, in bits per second.

        :param bitrate: The bitrate of this LiveEncodingHeartbeatIngestStream.
        :type: int
        """

        if bitrate is not None:
            if not isinstance(bitrate, int):
                raise TypeError("Invalid type for `bitrate`, type has to be `int`")

        self._bitrate = bitrate

    @property
    def samples_read_per_second_avg(self):
        # type: () -> float
        """Gets the samples_read_per_second_avg of this LiveEncodingHeartbeatIngestStream.

        Average number of samples/frames read per second.

        :return: The samples_read_per_second_avg of this LiveEncodingHeartbeatIngestStream.
        :rtype: float
        """
        return self._samples_read_per_second_avg

    @samples_read_per_second_avg.setter
    def samples_read_per_second_avg(self, samples_read_per_second_avg):
        # type: (float) -> None
        """Sets the samples_read_per_second_avg of this LiveEncodingHeartbeatIngestStream.

        Average number of samples/frames read per second.

        :param samples_read_per_second_avg: The samples_read_per_second_avg of this LiveEncodingHeartbeatIngestStream.
        :type: float
        """

        if samples_read_per_second_avg is not None:
            if not isinstance(samples_read_per_second_avg, (float, int)):
                raise TypeError("Invalid type for `samples_read_per_second_avg`, type has to be `float`")

        self._samples_read_per_second_avg = samples_read_per_second_avg

    @property
    def incoming_bitrate(self):
        # type: () -> float
        """Gets the incoming_bitrate of this LiveEncodingHeartbeatIngestStream.

        Incoming bitrate measured in bits per second.

        :return: The incoming_bitrate of this LiveEncodingHeartbeatIngestStream.
        :rtype: float
        """
        return self._incoming_bitrate

    @incoming_bitrate.setter
    def incoming_bitrate(self, incoming_bitrate):
        # type: (float) -> None
        """Sets the incoming_bitrate of this LiveEncodingHeartbeatIngestStream.

        Incoming bitrate measured in bits per second.

        :param incoming_bitrate: The incoming_bitrate of this LiveEncodingHeartbeatIngestStream.
        :type: float
        """

        if incoming_bitrate is not None:
            if not isinstance(incoming_bitrate, (float, int)):
                raise TypeError("Invalid type for `incoming_bitrate`, type has to be `float`")

        self._incoming_bitrate = incoming_bitrate

    @property
    def key_frame_interval_max(self):
        # type: () -> int
        """Gets the key_frame_interval_max of this LiveEncodingHeartbeatIngestStream.

        Largest encountered key-frame interval in milliseconds.

        :return: The key_frame_interval_max of this LiveEncodingHeartbeatIngestStream.
        :rtype: int
        """
        return self._key_frame_interval_max

    @key_frame_interval_max.setter
    def key_frame_interval_max(self, key_frame_interval_max):
        # type: (int) -> None
        """Sets the key_frame_interval_max of this LiveEncodingHeartbeatIngestStream.

        Largest encountered key-frame interval in milliseconds.

        :param key_frame_interval_max: The key_frame_interval_max of this LiveEncodingHeartbeatIngestStream.
        :type: int
        """

        if key_frame_interval_max is not None:
            if not isinstance(key_frame_interval_max, int):
                raise TypeError("Invalid type for `key_frame_interval_max`, type has to be `int`")

        self._key_frame_interval_max = key_frame_interval_max

    @property
    def key_frame_interval_avg(self):
        # type: () -> float
        """Gets the key_frame_interval_avg of this LiveEncodingHeartbeatIngestStream.

        Average key-frame interval in milliseconds.

        :return: The key_frame_interval_avg of this LiveEncodingHeartbeatIngestStream.
        :rtype: float
        """
        return self._key_frame_interval_avg

    @key_frame_interval_avg.setter
    def key_frame_interval_avg(self, key_frame_interval_avg):
        # type: (float) -> None
        """Sets the key_frame_interval_avg of this LiveEncodingHeartbeatIngestStream.

        Average key-frame interval in milliseconds.

        :param key_frame_interval_avg: The key_frame_interval_avg of this LiveEncodingHeartbeatIngestStream.
        :type: float
        """

        if key_frame_interval_avg is not None:
            if not isinstance(key_frame_interval_avg, (float, int)):
                raise TypeError("Invalid type for `key_frame_interval_avg`, type has to be `float`")

        self._key_frame_interval_avg = key_frame_interval_avg

    @property
    def last_timestamp(self):
        # type: () -> int
        """Gets the last_timestamp of this LiveEncodingHeartbeatIngestStream.

        Last presentation timestamp (PTS) of the stream.

        :return: The last_timestamp of this LiveEncodingHeartbeatIngestStream.
        :rtype: int
        """
        return self._last_timestamp

    @last_timestamp.setter
    def last_timestamp(self, last_timestamp):
        # type: (int) -> None
        """Sets the last_timestamp of this LiveEncodingHeartbeatIngestStream.

        Last presentation timestamp (PTS) of the stream.

        :param last_timestamp: The last_timestamp of this LiveEncodingHeartbeatIngestStream.
        :type: int
        """

        if last_timestamp is not None:
            if not isinstance(last_timestamp, int):
                raise TypeError("Invalid type for `last_timestamp`, type has to be `int`")

        self._last_timestamp = last_timestamp

    @property
    def last_timestamp_timescale(self):
        # type: () -> int
        """Gets the last_timestamp_timescale of this LiveEncodingHeartbeatIngestStream.

        Timescale of lastTimestamp

        :return: The last_timestamp_timescale of this LiveEncodingHeartbeatIngestStream.
        :rtype: int
        """
        return self._last_timestamp_timescale

    @last_timestamp_timescale.setter
    def last_timestamp_timescale(self, last_timestamp_timescale):
        # type: (int) -> None
        """Sets the last_timestamp_timescale of this LiveEncodingHeartbeatIngestStream.

        Timescale of lastTimestamp

        :param last_timestamp_timescale: The last_timestamp_timescale of this LiveEncodingHeartbeatIngestStream.
        :type: int
        """

        if last_timestamp_timescale is not None:
            if not isinstance(last_timestamp_timescale, int):
                raise TypeError("Invalid type for `last_timestamp_timescale`, type has to be `int`")

        self._last_timestamp_timescale = last_timestamp_timescale

    @property
    def number_of_audio_channels(self):
        # type: () -> int
        """Gets the number_of_audio_channels of this LiveEncodingHeartbeatIngestStream.

        Number of audio channels.

        :return: The number_of_audio_channels of this LiveEncodingHeartbeatIngestStream.
        :rtype: int
        """
        return self._number_of_audio_channels

    @number_of_audio_channels.setter
    def number_of_audio_channels(self, number_of_audio_channels):
        # type: (int) -> None
        """Sets the number_of_audio_channels of this LiveEncodingHeartbeatIngestStream.

        Number of audio channels.

        :param number_of_audio_channels: The number_of_audio_channels of this LiveEncodingHeartbeatIngestStream.
        :type: int
        """

        if number_of_audio_channels is not None:
            if not isinstance(number_of_audio_channels, int):
                raise TypeError("Invalid type for `number_of_audio_channels`, type has to be `int`")

        self._number_of_audio_channels = number_of_audio_channels

    @property
    def audio_channel_format(self):
        # type: () -> string_types
        """Gets the audio_channel_format of this LiveEncodingHeartbeatIngestStream.

        Format of the audio channel.

        :return: The audio_channel_format of this LiveEncodingHeartbeatIngestStream.
        :rtype: string_types
        """
        return self._audio_channel_format

    @audio_channel_format.setter
    def audio_channel_format(self, audio_channel_format):
        # type: (string_types) -> None
        """Sets the audio_channel_format of this LiveEncodingHeartbeatIngestStream.

        Format of the audio channel.

        :param audio_channel_format: The audio_channel_format of this LiveEncodingHeartbeatIngestStream.
        :type: string_types
        """

        if audio_channel_format is not None:
            if not isinstance(audio_channel_format, string_types):
                raise TypeError("Invalid type for `audio_channel_format`, type has to be `string_types`")

        self._audio_channel_format = audio_channel_format

    @property
    def last_arrival_time(self):
        # type: () -> datetime
        """Gets the last_arrival_time of this LiveEncodingHeartbeatIngestStream.

        lastArrivalTime timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :return: The last_arrival_time of this LiveEncodingHeartbeatIngestStream.
        :rtype: datetime
        """
        return self._last_arrival_time

    @last_arrival_time.setter
    def last_arrival_time(self, last_arrival_time):
        # type: (datetime) -> None
        """Sets the last_arrival_time of this LiveEncodingHeartbeatIngestStream.

        lastArrivalTime timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :param last_arrival_time: The last_arrival_time of this LiveEncodingHeartbeatIngestStream.
        :type: datetime
        """

        if last_arrival_time is not None:
            if not isinstance(last_arrival_time, datetime):
                raise TypeError("Invalid type for `last_arrival_time`, type has to be `datetime`")

        self._last_arrival_time = last_arrival_time

    @property
    def healthy(self):
        # type: () -> bool
        """Gets the healthy of this LiveEncodingHeartbeatIngestStream.

        Indicates whether this particular stream is healthy.

        :return: The healthy of this LiveEncodingHeartbeatIngestStream.
        :rtype: bool
        """
        return self._healthy

    @healthy.setter
    def healthy(self, healthy):
        # type: (bool) -> None
        """Sets the healthy of this LiveEncodingHeartbeatIngestStream.

        Indicates whether this particular stream is healthy.

        :param healthy: The healthy of this LiveEncodingHeartbeatIngestStream.
        :type: bool
        """

        if healthy is not None:
            if not isinstance(healthy, bool):
                raise TypeError("Invalid type for `healthy`, type has to be `bool`")

        self._healthy = healthy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveEncodingHeartbeatIngestStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.clock_synchronization_mode import ClockSynchronizationMode
import pprint
import six


class AdInsertionSettings(object):
    @poscheck_model
    def __init__(self,
                 enable_esam_media_point_insertion=None,
                 clock_synchronization_mode=None):
        # type: (bool, ClockSynchronizationMode) -> None

        self._enable_esam_media_point_insertion = None
        self._clock_synchronization_mode = None
        self.discriminator = None

        if enable_esam_media_point_insertion is not None:
            self.enable_esam_media_point_insertion = enable_esam_media_point_insertion
        if clock_synchronization_mode is not None:
            self.clock_synchronization_mode = clock_synchronization_mode

    @property
    def openapi_types(self):
        types = {
            'enable_esam_media_point_insertion': 'bool',
            'clock_synchronization_mode': 'ClockSynchronizationMode'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'enable_esam_media_point_insertion': 'enableEsamMediaPointInsertion',
            'clock_synchronization_mode': 'clockSynchronizationMode'
        }
        return attributes

    @property
    def enable_esam_media_point_insertion(self):
        # type: () -> bool
        """Gets the enable_esam_media_point_insertion of this AdInsertionSettings.

        Enabling this allows on-demand insertion of ESAM MediaPoints. When enabled, the encoder ensures that at least one SCTE-35 data stream is available.

        :return: The enable_esam_media_point_insertion of this AdInsertionSettings.
        :rtype: bool
        """
        return self._enable_esam_media_point_insertion

    @enable_esam_media_point_insertion.setter
    def enable_esam_media_point_insertion(self, enable_esam_media_point_insertion):
        # type: (bool) -> None
        """Sets the enable_esam_media_point_insertion of this AdInsertionSettings.

        Enabling this allows on-demand insertion of ESAM MediaPoints. When enabled, the encoder ensures that at least one SCTE-35 data stream is available.

        :param enable_esam_media_point_insertion: The enable_esam_media_point_insertion of this AdInsertionSettings.
        :type: bool
        """

        if enable_esam_media_point_insertion is not None:
            if not isinstance(enable_esam_media_point_insertion, bool):
                raise TypeError("Invalid type for `enable_esam_media_point_insertion`, type has to be `bool`")

        self._enable_esam_media_point_insertion = enable_esam_media_point_insertion

    @property
    def clock_synchronization_mode(self):
        # type: () -> ClockSynchronizationMode
        """Gets the clock_synchronization_mode of this AdInsertionSettings.

        Mode of clock synchronization during ad insertion.  If an HLS manifest is configured that has a PDT source set, the encoder defaults to the equivalent clockSynchronizationMode.  If both, HLS PDT source and clockSynchronizationMode, are set and don't match, the encoding will fail. 

        :return: The clock_synchronization_mode of this AdInsertionSettings.
        :rtype: ClockSynchronizationMode
        """
        return self._clock_synchronization_mode

    @clock_synchronization_mode.setter
    def clock_synchronization_mode(self, clock_synchronization_mode):
        # type: (ClockSynchronizationMode) -> None
        """Sets the clock_synchronization_mode of this AdInsertionSettings.

        Mode of clock synchronization during ad insertion.  If an HLS manifest is configured that has a PDT source set, the encoder defaults to the equivalent clockSynchronizationMode.  If both, HLS PDT source and clockSynchronizationMode, are set and don't match, the encoding will fail. 

        :param clock_synchronization_mode: The clock_synchronization_mode of this AdInsertionSettings.
        :type: ClockSynchronizationMode
        """

        if clock_synchronization_mode is not None:
            if not isinstance(clock_synchronization_mode, ClockSynchronizationMode):
                raise TypeError("Invalid type for `clock_synchronization_mode`, type has to be `ClockSynchronizationMode`")

        self._clock_synchronization_mode = clock_synchronization_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdInsertionSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.streams_ad_config_response import StreamsAdConfigResponse
from bitmovin_api_sdk.models.streams_domain_restriction_response import StreamsDomainRestrictionResponse
from bitmovin_api_sdk.models.streams_live_life_cycle import StreamsLiveLifeCycle
from bitmovin_api_sdk.models.streams_response import StreamsResponse
from bitmovin_api_sdk.models.streams_style_config_response import StreamsStyleConfigResponse
from bitmovin_api_sdk.models.streams_trimming_status import StreamsTrimmingStatus
from bitmovin_api_sdk.models.streams_type import StreamsType
import pprint
import six


class StreamsLiveResponse(StreamsResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 title=None,
                 description=None,
                 created_at=None,
                 type_=None,
                 stream_key=None,
                 life_cycle=None,
                 style_config=None,
                 poster_url=None,
                 ad_config=None,
                 domain_restriction=None,
                 trimming=None):
        # type: (string_types, string_types, string_types, datetime, StreamsType, string_types, StreamsLiveLifeCycle, StreamsStyleConfigResponse, string_types, StreamsAdConfigResponse, StreamsDomainRestrictionResponse, StreamsTrimmingStatus) -> None
        super(StreamsLiveResponse, self).__init__(id_=id_, title=title, description=description, created_at=created_at, type_=type_)

        self._stream_key = None
        self._life_cycle = None
        self._style_config = None
        self._poster_url = None
        self._ad_config = None
        self._domain_restriction = None
        self._trimming = None
        self.discriminator = None

        if stream_key is not None:
            self.stream_key = stream_key
        if life_cycle is not None:
            self.life_cycle = life_cycle
        if style_config is not None:
            self.style_config = style_config
        if poster_url is not None:
            self.poster_url = poster_url
        if ad_config is not None:
            self.ad_config = ad_config
        if domain_restriction is not None:
            self.domain_restriction = domain_restriction
        if trimming is not None:
            self.trimming = trimming

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(StreamsLiveResponse, self), 'openapi_types'):
            types = getattr(super(StreamsLiveResponse, self), 'openapi_types')

        types.update({
            'stream_key': 'string_types',
            'life_cycle': 'StreamsLiveLifeCycle',
            'style_config': 'StreamsStyleConfigResponse',
            'poster_url': 'string_types',
            'ad_config': 'StreamsAdConfigResponse',
            'domain_restriction': 'StreamsDomainRestrictionResponse',
            'trimming': 'StreamsTrimmingStatus'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(StreamsLiveResponse, self), 'attribute_map'):
            attributes = getattr(super(StreamsLiveResponse, self), 'attribute_map')

        attributes.update({
            'stream_key': 'streamKey',
            'life_cycle': 'lifeCycle',
            'style_config': 'styleConfig',
            'poster_url': 'posterUrl',
            'ad_config': 'adConfig',
            'domain_restriction': 'domainRestriction',
            'trimming': 'trimming'
        })
        return attributes

    @property
    def stream_key(self):
        # type: () -> string_types
        """Gets the stream_key of this StreamsLiveResponse.

        The streamKey of the stream

        :return: The stream_key of this StreamsLiveResponse.
        :rtype: string_types
        """
        return self._stream_key

    @stream_key.setter
    def stream_key(self, stream_key):
        # type: (string_types) -> None
        """Sets the stream_key of this StreamsLiveResponse.

        The streamKey of the stream

        :param stream_key: The stream_key of this StreamsLiveResponse.
        :type: string_types
        """

        if stream_key is not None:
            if not isinstance(stream_key, string_types):
                raise TypeError("Invalid type for `stream_key`, type has to be `string_types`")

        self._stream_key = stream_key

    @property
    def life_cycle(self):
        # type: () -> StreamsLiveLifeCycle
        """Gets the life_cycle of this StreamsLiveResponse.

        The life cycle of the stream

        :return: The life_cycle of this StreamsLiveResponse.
        :rtype: StreamsLiveLifeCycle
        """
        return self._life_cycle

    @life_cycle.setter
    def life_cycle(self, life_cycle):
        # type: (StreamsLiveLifeCycle) -> None
        """Sets the life_cycle of this StreamsLiveResponse.

        The life cycle of the stream

        :param life_cycle: The life_cycle of this StreamsLiveResponse.
        :type: StreamsLiveLifeCycle
        """

        if life_cycle is not None:
            if not isinstance(life_cycle, StreamsLiveLifeCycle):
                raise TypeError("Invalid type for `life_cycle`, type has to be `StreamsLiveLifeCycle`")

        self._life_cycle = life_cycle

    @property
    def style_config(self):
        # type: () -> StreamsStyleConfigResponse
        """Gets the style_config of this StreamsLiveResponse.


        :return: The style_config of this StreamsLiveResponse.
        :rtype: StreamsStyleConfigResponse
        """
        return self._style_config

    @style_config.setter
    def style_config(self, style_config):
        # type: (StreamsStyleConfigResponse) -> None
        """Sets the style_config of this StreamsLiveResponse.


        :param style_config: The style_config of this StreamsLiveResponse.
        :type: StreamsStyleConfigResponse
        """

        if style_config is not None:
            if not isinstance(style_config, StreamsStyleConfigResponse):
                raise TypeError("Invalid type for `style_config`, type has to be `StreamsStyleConfigResponse`")

        self._style_config = style_config

    @property
    def poster_url(self):
        # type: () -> string_types
        """Gets the poster_url of this StreamsLiveResponse.

        Poster URL

        :return: The poster_url of this StreamsLiveResponse.
        :rtype: string_types
        """
        return self._poster_url

    @poster_url.setter
    def poster_url(self, poster_url):
        # type: (string_types) -> None
        """Sets the poster_url of this StreamsLiveResponse.

        Poster URL

        :param poster_url: The poster_url of this StreamsLiveResponse.
        :type: string_types
        """

        if poster_url is not None:
            if not isinstance(poster_url, string_types):
                raise TypeError("Invalid type for `poster_url`, type has to be `string_types`")

        self._poster_url = poster_url

    @property
    def ad_config(self):
        # type: () -> StreamsAdConfigResponse
        """Gets the ad_config of this StreamsLiveResponse.


        :return: The ad_config of this StreamsLiveResponse.
        :rtype: StreamsAdConfigResponse
        """
        return self._ad_config

    @ad_config.setter
    def ad_config(self, ad_config):
        # type: (StreamsAdConfigResponse) -> None
        """Sets the ad_config of this StreamsLiveResponse.


        :param ad_config: The ad_config of this StreamsLiveResponse.
        :type: StreamsAdConfigResponse
        """

        if ad_config is not None:
            if not isinstance(ad_config, StreamsAdConfigResponse):
                raise TypeError("Invalid type for `ad_config`, type has to be `StreamsAdConfigResponse`")

        self._ad_config = ad_config

    @property
    def domain_restriction(self):
        # type: () -> StreamsDomainRestrictionResponse
        """Gets the domain_restriction of this StreamsLiveResponse.


        :return: The domain_restriction of this StreamsLiveResponse.
        :rtype: StreamsDomainRestrictionResponse
        """
        return self._domain_restriction

    @domain_restriction.setter
    def domain_restriction(self, domain_restriction):
        # type: (StreamsDomainRestrictionResponse) -> None
        """Sets the domain_restriction of this StreamsLiveResponse.


        :param domain_restriction: The domain_restriction of this StreamsLiveResponse.
        :type: StreamsDomainRestrictionResponse
        """

        if domain_restriction is not None:
            if not isinstance(domain_restriction, StreamsDomainRestrictionResponse):
                raise TypeError("Invalid type for `domain_restriction`, type has to be `StreamsDomainRestrictionResponse`")

        self._domain_restriction = domain_restriction

    @property
    def trimming(self):
        # type: () -> StreamsTrimmingStatus
        """Gets the trimming of this StreamsLiveResponse.

        Stream trimming information

        :return: The trimming of this StreamsLiveResponse.
        :rtype: StreamsTrimmingStatus
        """
        return self._trimming

    @trimming.setter
    def trimming(self, trimming):
        # type: (StreamsTrimmingStatus) -> None
        """Sets the trimming of this StreamsLiveResponse.

        Stream trimming information

        :param trimming: The trimming of this StreamsLiveResponse.
        :type: StreamsTrimmingStatus
        """

        if trimming is not None:
            if not isinstance(trimming, StreamsTrimmingStatus):
                raise TypeError("Invalid type for `trimming`, type has to be `StreamsTrimmingStatus`")

        self._trimming = trimming

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(StreamsLiveResponse, self), "to_dict"):
            result = super(StreamsLiveResponse, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamsLiveResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.live.encodings.encodings_api import EncodingsApi
from bitmovin_api_sdk.encoding.live.encodings.actions.actions_api import ActionsApi
from bitmovin_api_sdk.encoding.live.encodings.dns_mappings.dns_mappings_api import DnsMappingsApi



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.esam_media_point import EsamMediaPoint
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class MediaPointsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(MediaPointsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, esam_media_point, **kwargs):
        # type: (string_types, EsamMediaPoint, dict) -> EsamMediaPoint
        """Create ESAM media point for live stream

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :param esam_media_point: ESAM media point
        :type esam_media_point: EsamMediaPoint, required
        :return: ESAM media point
        :rtype: EsamMediaPoint
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/live/esam/media-points',
            esam_media_point,
            path_params={'encoding_id': encoding_id},
            type=EsamMediaPoint,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
import pprint
import six


class KantarWatermark(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 login=None,
                 password=None,
                 license_id=None,
                 channel_name=None,
                 content_reference=None,
                 server_url=None,
                 report_outputs=None):
        # type: (string_types, string_types, string_types, int, string_types, string_types, string_types, list[EncodingOutput]) -> None
        super(KantarWatermark, self).__init__(id_=id_)

        self._login = None
        self._password = None
        self._license_id = None
        self._channel_name = None
        self._content_reference = None
        self._server_url = None
        self._report_outputs = list()
        self.discriminator = None

        if login is not None:
            self.login = login
        if password is not None:
            self.password = password
        if license_id is not None:
            self.license_id = license_id
        if channel_name is not None:
            self.channel_name = channel_name
        if content_reference is not None:
            self.content_reference = content_reference
        if server_url is not None:
            self.server_url = server_url
        if report_outputs is not None:
            self.report_outputs = report_outputs

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(KantarWatermark, self), 'openapi_types'):
            types = getattr(super(KantarWatermark, self), 'openapi_types')

        types.update({
            'login': 'string_types',
            'password': 'string_types',
            'license_id': 'int',
            'channel_name': 'string_types',
            'content_reference': 'string_types',
            'server_url': 'string_types',
            'report_outputs': 'list[EncodingOutput]'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(KantarWatermark, self), 'attribute_map'):
            attributes = getattr(super(KantarWatermark, self), 'attribute_map')

        attributes.update({
            'login': 'login',
            'password': 'password',
            'license_id': 'licenseId',
            'channel_name': 'channelName',
            'content_reference': 'contentReference',
            'server_url': 'serverUrl',
            'report_outputs': 'reportOutputs'
        })
        return attributes

    @property
    def login(self):
        # type: () -> string_types
        """Gets the login of this KantarWatermark.

        Username used to authenticate with the Kantar watermarking service. (required)

        :return: The login of this KantarWatermark.
        :rtype: string_types
        """
        return self._login

    @login.setter
    def login(self, login):
        # type: (string_types) -> None
        """Sets the login of this KantarWatermark.

        Username used to authenticate with the Kantar watermarking service. (required)

        :param login: The login of this KantarWatermark.
        :type: string_types
        """

        if login is not None:
            if not isinstance(login, string_types):
                raise TypeError("Invalid type for `login`, type has to be `string_types`")

        self._login = login

    @property
    def password(self):
        # type: () -> string_types
        """Gets the password of this KantarWatermark.

        Password associated with the provided login for authentication. (required)

        :return: The password of this KantarWatermark.
        :rtype: string_types
        """
        return self._password

    @password.setter
    def password(self, password):
        # type: (string_types) -> None
        """Sets the password of this KantarWatermark.

        Password associated with the provided login for authentication. (required)

        :param password: The password of this KantarWatermark.
        :type: string_types
        """

        if password is not None:
            if not isinstance(password, string_types):
                raise TypeError("Invalid type for `password`, type has to be `string_types`")

        self._password = password

    @property
    def license_id(self):
        # type: () -> int
        """Gets the license_id of this KantarWatermark.

        Identifier of the Kantar license to be used when processing the audio watermark. (required)

        :return: The license_id of this KantarWatermark.
        :rtype: int
        """
        return self._license_id

    @license_id.setter
    def license_id(self, license_id):
        # type: (int) -> None
        """Sets the license_id of this KantarWatermark.

        Identifier of the Kantar license to be used when processing the audio watermark. (required)

        :param license_id: The license_id of this KantarWatermark.
        :type: int
        """

        if license_id is not None:
            if not isinstance(license_id, int):
                raise TypeError("Invalid type for `license_id`, type has to be `int`")

        self._license_id = license_id

    @property
    def channel_name(self):
        # type: () -> string_types
        """Gets the channel_name of this KantarWatermark.

        Name of the distribution channel associated with the audio content being watermarked. (required)

        :return: The channel_name of this KantarWatermark.
        :rtype: string_types
        """
        return self._channel_name

    @channel_name.setter
    def channel_name(self, channel_name):
        # type: (string_types) -> None
        """Sets the channel_name of this KantarWatermark.

        Name of the distribution channel associated with the audio content being watermarked. (required)

        :param channel_name: The channel_name of this KantarWatermark.
        :type: string_types
        """

        if channel_name is not None:
            if not isinstance(channel_name, string_types):
                raise TypeError("Invalid type for `channel_name`, type has to be `string_types`")

        self._channel_name = channel_name

    @property
    def content_reference(self):
        # type: () -> string_types
        """Gets the content_reference of this KantarWatermark.

        Unique reference or identifier for the audio content that will be processed. (required)

        :return: The content_reference of this KantarWatermark.
        :rtype: string_types
        """
        return self._content_reference

    @content_reference.setter
    def content_reference(self, content_reference):
        # type: (string_types) -> None
        """Sets the content_reference of this KantarWatermark.

        Unique reference or identifier for the audio content that will be processed. (required)

        :param content_reference: The content_reference of this KantarWatermark.
        :type: string_types
        """

        if content_reference is not None:
            if not isinstance(content_reference, string_types):
                raise TypeError("Invalid type for `content_reference`, type has to be `string_types`")

        self._content_reference = content_reference

    @property
    def server_url(self):
        # type: () -> string_types
        """Gets the server_url of this KantarWatermark.

        URL of the Kantar server endpoint used to apply or validate the audio watermark. (required)

        :return: The server_url of this KantarWatermark.
        :rtype: string_types
        """
        return self._server_url

    @server_url.setter
    def server_url(self, server_url):
        # type: (string_types) -> None
        """Sets the server_url of this KantarWatermark.

        URL of the Kantar server endpoint used to apply or validate the audio watermark. (required)

        :param server_url: The server_url of this KantarWatermark.
        :type: string_types
        """

        if server_url is not None:
            if not isinstance(server_url, string_types):
                raise TypeError("Invalid type for `server_url`, type has to be `string_types`")

        self._server_url = server_url

    @property
    def report_outputs(self):
        # type: () -> list[EncodingOutput]
        """Gets the report_outputs of this KantarWatermark.

        The outputs where the processing report should be delivered. (required)

        :return: The report_outputs of this KantarWatermark.
        :rtype: list[EncodingOutput]
        """
        return self._report_outputs

    @report_outputs.setter
    def report_outputs(self, report_outputs):
        # type: (list) -> None
        """Sets the report_outputs of this KantarWatermark.

        The outputs where the processing report should be delivered. (required)

        :param report_outputs: The report_outputs of this KantarWatermark.
        :type: list[EncodingOutput]
        """

        if report_outputs is not None:
            if not isinstance(report_outputs, list):
                raise TypeError("Invalid type for `report_outputs`, type has to be `list[EncodingOutput]`")

        self._report_outputs = report_outputs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(KantarWatermark, self), "to_dict"):
            result = super(KantarWatermark, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KantarWatermark):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class SceneTension(Enum):
    EXTREME = "EXTREME"
    HIGH = "HIGH"
    MODERATE = "MODERATE"
    LOW = "LOW"
    UNKNOWN = "UNKNOWN"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.aws_cloud_region import AwsCloudRegion
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
import pprint
import six


class AwsAccountRegionSettings(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 limit_parallel_encodings=None,
                 security_group_id=None,
                 subnet_id=None,
                 ssh_port=None,
                 region=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, string_types, string_types, int, AwsCloudRegion) -> None
        super(AwsAccountRegionSettings, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._limit_parallel_encodings = None
        self._security_group_id = None
        self._subnet_id = None
        self._ssh_port = None
        self._region = None
        self.discriminator = None

        if limit_parallel_encodings is not None:
            self.limit_parallel_encodings = limit_parallel_encodings
        if security_group_id is not None:
            self.security_group_id = security_group_id
        if subnet_id is not None:
            self.subnet_id = subnet_id
        if ssh_port is not None:
            self.ssh_port = ssh_port
        if region is not None:
            self.region = region

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AwsAccountRegionSettings, self), 'openapi_types'):
            types = getattr(super(AwsAccountRegionSettings, self), 'openapi_types')

        types.update({
            'limit_parallel_encodings': 'int',
            'security_group_id': 'string_types',
            'subnet_id': 'string_types',
            'ssh_port': 'int',
            'region': 'AwsCloudRegion'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AwsAccountRegionSettings, self), 'attribute_map'):
            attributes = getattr(super(AwsAccountRegionSettings, self), 'attribute_map')

        attributes.update({
            'limit_parallel_encodings': 'limitParallelEncodings',
            'security_group_id': 'securityGroupId',
            'subnet_id': 'subnetId',
            'ssh_port': 'sshPort',
            'region': 'region'
        })
        return attributes

    @property
    def limit_parallel_encodings(self):
        # type: () -> int
        """Gets the limit_parallel_encodings of this AwsAccountRegionSettings.

        Limit for the amount of running encodings at a time. Leave empty for no limit.

        :return: The limit_parallel_encodings of this AwsAccountRegionSettings.
        :rtype: int
        """
        return self._limit_parallel_encodings

    @limit_parallel_encodings.setter
    def limit_parallel_encodings(self, limit_parallel_encodings):
        # type: (int) -> None
        """Sets the limit_parallel_encodings of this AwsAccountRegionSettings.

        Limit for the amount of running encodings at a time. Leave empty for no limit.

        :param limit_parallel_encodings: The limit_parallel_encodings of this AwsAccountRegionSettings.
        :type: int
        """

        if limit_parallel_encodings is not None:
            if not isinstance(limit_parallel_encodings, int):
                raise TypeError("Invalid type for `limit_parallel_encodings`, type has to be `int`")

        self._limit_parallel_encodings = limit_parallel_encodings

    @property
    def security_group_id(self):
        # type: () -> string_types
        """Gets the security_group_id of this AwsAccountRegionSettings.

        Id of the security group for encoding instances (required)

        :return: The security_group_id of this AwsAccountRegionSettings.
        :rtype: string_types
        """
        return self._security_group_id

    @security_group_id.setter
    def security_group_id(self, security_group_id):
        # type: (string_types) -> None
        """Sets the security_group_id of this AwsAccountRegionSettings.

        Id of the security group for encoding instances (required)

        :param security_group_id: The security_group_id of this AwsAccountRegionSettings.
        :type: string_types
        """

        if security_group_id is not None:
            if not isinstance(security_group_id, string_types):
                raise TypeError("Invalid type for `security_group_id`, type has to be `string_types`")

        self._security_group_id = security_group_id

    @property
    def subnet_id(self):
        # type: () -> string_types
        """Gets the subnet_id of this AwsAccountRegionSettings.

        Id of the subnet for encoding instances (required)

        :return: The subnet_id of this AwsAccountRegionSettings.
        :rtype: string_types
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        # type: (string_types) -> None
        """Sets the subnet_id of this AwsAccountRegionSettings.

        Id of the subnet for encoding instances (required)

        :param subnet_id: The subnet_id of this AwsAccountRegionSettings.
        :type: string_types
        """

        if subnet_id is not None:
            if not isinstance(subnet_id, string_types):
                raise TypeError("Invalid type for `subnet_id`, type has to be `string_types`")

        self._subnet_id = subnet_id

    @property
    def ssh_port(self):
        # type: () -> int
        """Gets the ssh_port of this AwsAccountRegionSettings.

        Custom SSH port. Valid values: 1 - 65535. Leave empty if the default SSH port 22 is OK.

        :return: The ssh_port of this AwsAccountRegionSettings.
        :rtype: int
        """
        return self._ssh_port

    @ssh_port.setter
    def ssh_port(self, ssh_port):
        # type: (int) -> None
        """Sets the ssh_port of this AwsAccountRegionSettings.

        Custom SSH port. Valid values: 1 - 65535. Leave empty if the default SSH port 22 is OK.

        :param ssh_port: The ssh_port of this AwsAccountRegionSettings.
        :type: int
        """

        if ssh_port is not None:
            if ssh_port is not None and ssh_port > 65535:
                raise ValueError("Invalid value for `ssh_port`, must be a value less than or equal to `65535`")
            if ssh_port is not None and ssh_port < 1:
                raise ValueError("Invalid value for `ssh_port`, must be a value greater than or equal to `1`")
            if not isinstance(ssh_port, int):
                raise TypeError("Invalid type for `ssh_port`, type has to be `int`")

        self._ssh_port = ssh_port

    @property
    def region(self):
        # type: () -> AwsCloudRegion
        """Gets the region of this AwsAccountRegionSettings.


        :return: The region of this AwsAccountRegionSettings.
        :rtype: AwsCloudRegion
        """
        return self._region

    @region.setter
    def region(self, region):
        # type: (AwsCloudRegion) -> None
        """Sets the region of this AwsAccountRegionSettings.


        :param region: The region of this AwsAccountRegionSettings.
        :type: AwsCloudRegion
        """

        if region is not None:
            if not isinstance(region, AwsCloudRegion):
                raise TypeError("Invalid type for `region`, type has to be `AwsCloudRegion`")

        self._region = region

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AwsAccountRegionSettings, self), "to_dict"):
            result = super(AwsAccountRegionSettings, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AwsAccountRegionSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.kantar_watermark import KantarWatermark
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class KantarWatermarkApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(KantarWatermarkApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, kantar_watermark, **kwargs):
        # type: (string_types, KantarWatermark, dict) -> KantarWatermark
        """Create or replace the Kantar Watermark for an encoding

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param kantar_watermark: The Kantar Watermark to be created
        :type kantar_watermark: KantarWatermark, required
        :return: Kantar Watermark
        :rtype: KantarWatermark
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/kantar-watermark',
            kantar_watermark,
            path_params={'encoding_id': encoding_id},
            type=KantarWatermark,
            **kwargs
        )

    def delete(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete the Kantar Watermark for an encoding

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :return: Id of the Kantar Watermark
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/kantar-watermark',
            path_params={'encoding_id': encoding_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> KantarWatermark
        """Get the Kantar Watermark for an encoding

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :return:
        :rtype: KantarWatermark
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/kantar-watermark',
            path_params={'encoding_id': encoding_id},
            type=KantarWatermark,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class EsamSignal(object):
    @poscheck_model
    def __init__(self,
                 offset=None,
                 binary=None,
                 interval=None,
                 end=None):
        # type: (string_types, string_types, string_types, string_types) -> None

        self._offset = None
        self._binary = None
        self._interval = None
        self._end = None
        self.discriminator = None

        if offset is not None:
            self.offset = offset
        if binary is not None:
            self.binary = binary
        if interval is not None:
            self.interval = interval
        if end is not None:
            self.end = end

    @property
    def openapi_types(self):
        types = {
            'offset': 'string_types',
            'binary': 'string_types',
            'interval': 'string_types',
            'end': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'offset': 'offset',
            'binary': 'binary',
            'interval': 'interval',
            'end': 'end'
        }
        return attributes

    @property
    def offset(self):
        # type: () -> string_types
        """Gets the offset of this EsamSignal.

        The offset from the matched signal in ISO 8601 duration format, accurate to milliseconds

        :return: The offset of this EsamSignal.
        :rtype: string_types
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        # type: (string_types) -> None
        """Sets the offset of this EsamSignal.

        The offset from the matched signal in ISO 8601 duration format, accurate to milliseconds

        :param offset: The offset of this EsamSignal.
        :type: string_types
        """

        if offset is not None:
            if not isinstance(offset, string_types):
                raise TypeError("Invalid type for `offset`, type has to be `string_types`")

        self._offset = offset

    @property
    def binary(self):
        # type: () -> string_types
        """Gets the binary of this EsamSignal.

        Base64-encoded SCTE-35 binary data to be inserted into the stream (required)

        :return: The binary of this EsamSignal.
        :rtype: string_types
        """
        return self._binary

    @binary.setter
    def binary(self, binary):
        # type: (string_types) -> None
        """Sets the binary of this EsamSignal.

        Base64-encoded SCTE-35 binary data to be inserted into the stream (required)

        :param binary: The binary of this EsamSignal.
        :type: string_types
        """

        if binary is not None:
            if not isinstance(binary, string_types):
                raise TypeError("Invalid type for `binary`, type has to be `string_types`")

        self._binary = binary

    @property
    def interval(self):
        # type: () -> string_types
        """Gets the interval of this EsamSignal.

        Interval in ISO 8601 duration format for which the signal should be repeated.  A signal may be specified as repeating when the interval and end attributes are present.  In this case, the signal is executed at the time specified by offset and again at the time  specified by adding interval to offset. This should be continued until reaching the duration  of offset + end. 

        :return: The interval of this EsamSignal.
        :rtype: string_types
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        # type: (string_types) -> None
        """Sets the interval of this EsamSignal.

        Interval in ISO 8601 duration format for which the signal should be repeated.  A signal may be specified as repeating when the interval and end attributes are present.  In this case, the signal is executed at the time specified by offset and again at the time  specified by adding interval to offset. This should be continued until reaching the duration  of offset + end. 

        :param interval: The interval of this EsamSignal.
        :type: string_types
        """

        if interval is not None:
            if not isinstance(interval, string_types):
                raise TypeError("Invalid type for `interval`, type has to be `string_types`")

        self._interval = interval

    @property
    def end(self):
        # type: () -> string_types
        """Gets the end of this EsamSignal.

        End duration in ISO 8601 duration format when a repeated signal should stop being repeated

        :return: The end of this EsamSignal.
        :rtype: string_types
        """
        return self._end

    @end.setter
    def end(self, end):
        # type: (string_types) -> None
        """Sets the end of this EsamSignal.

        End duration in ISO 8601 duration format when a repeated signal should stop being repeated

        :param end: The end of this EsamSignal.
        :type: string_types
        """

        if end is not None:
            if not isinstance(end, string_types):
                raise TypeError("Invalid type for `end`, type has to be `string_types`")

        self._end = end

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EsamSignal):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.clock_synchronization_mode import ClockSynchronizationMode
from bitmovin_api_sdk.models.live_encoding_event_name import LiveEncodingEventName
import pprint
import six


class LiveEncodingStatsEventDetails(object):
    @poscheck_model
    def __init__(self,
                 event_type=None,
                 message=None,
                 source=None,
                 year=None,
                 month=None,
                 day=None,
                 hours=None,
                 minutes=None,
                 seconds=None,
                 micro_seconds=None):
        # type: (LiveEncodingEventName, string_types, ClockSynchronizationMode, int, int, int, int, int, int, int) -> None

        self._event_type = None
        self._message = None
        self._source = None
        self._year = None
        self._month = None
        self._day = None
        self._hours = None
        self._minutes = None
        self._seconds = None
        self._micro_seconds = None
        self.discriminator = None

        if event_type is not None:
            self.event_type = event_type
        if message is not None:
            self.message = message
        if source is not None:
            self.source = source
        if year is not None:
            self.year = year
        if month is not None:
            self.month = month
        if day is not None:
            self.day = day
        if hours is not None:
            self.hours = hours
        if minutes is not None:
            self.minutes = minutes
        if seconds is not None:
            self.seconds = seconds
        if micro_seconds is not None:
            self.micro_seconds = micro_seconds

    @property
    def openapi_types(self):
        types = {
            'event_type': 'LiveEncodingEventName',
            'message': 'string_types',
            'source': 'ClockSynchronizationMode',
            'year': 'int',
            'month': 'int',
            'day': 'int',
            'hours': 'int',
            'minutes': 'int',
            'seconds': 'int',
            'micro_seconds': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'event_type': 'eventType',
            'message': 'message',
            'source': 'source',
            'year': 'year',
            'month': 'month',
            'day': 'day',
            'hours': 'hours',
            'minutes': 'minutes',
            'seconds': 'seconds',
            'micro_seconds': 'microSeconds'
        }
        return attributes

    @property
    def event_type(self):
        # type: () -> LiveEncodingEventName
        """Gets the event_type of this LiveEncodingStatsEventDetails.


        :return: The event_type of this LiveEncodingStatsEventDetails.
        :rtype: LiveEncodingEventName
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        # type: (LiveEncodingEventName) -> None
        """Sets the event_type of this LiveEncodingStatsEventDetails.


        :param event_type: The event_type of this LiveEncodingStatsEventDetails.
        :type: LiveEncodingEventName
        """

        if event_type is not None:
            if not isinstance(event_type, LiveEncodingEventName):
                raise TypeError("Invalid type for `event_type`, type has to be `LiveEncodingEventName`")

        self._event_type = event_type

    @property
    def message(self):
        # type: () -> string_types
        """Gets the message of this LiveEncodingStatsEventDetails.

        Short description of the event

        :return: The message of this LiveEncodingStatsEventDetails.
        :rtype: string_types
        """
        return self._message

    @message.setter
    def message(self, message):
        # type: (string_types) -> None
        """Sets the message of this LiveEncodingStatsEventDetails.

        Short description of the event

        :param message: The message of this LiveEncodingStatsEventDetails.
        :type: string_types
        """

        if message is not None:
            if not isinstance(message, string_types):
                raise TypeError("Invalid type for `message`, type has to be `string_types`")

        self._message = message

    @property
    def source(self):
        # type: () -> ClockSynchronizationMode
        """Gets the source of this LiveEncodingStatsEventDetails.

        Source used for clock-synchronization

        :return: The source of this LiveEncodingStatsEventDetails.
        :rtype: ClockSynchronizationMode
        """
        return self._source

    @source.setter
    def source(self, source):
        # type: (ClockSynchronizationMode) -> None
        """Sets the source of this LiveEncodingStatsEventDetails.

        Source used for clock-synchronization

        :param source: The source of this LiveEncodingStatsEventDetails.
        :type: ClockSynchronizationMode
        """

        if source is not None:
            if not isinstance(source, ClockSynchronizationMode):
                raise TypeError("Invalid type for `source`, type has to be `ClockSynchronizationMode`")

        self._source = source

    @property
    def year(self):
        # type: () -> int
        """Gets the year of this LiveEncodingStatsEventDetails.

        Year specified in picture timing

        :return: The year of this LiveEncodingStatsEventDetails.
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year):
        # type: (int) -> None
        """Sets the year of this LiveEncodingStatsEventDetails.

        Year specified in picture timing

        :param year: The year of this LiveEncodingStatsEventDetails.
        :type: int
        """

        if year is not None:
            if not isinstance(year, int):
                raise TypeError("Invalid type for `year`, type has to be `int`")

        self._year = year

    @property
    def month(self):
        # type: () -> int
        """Gets the month of this LiveEncodingStatsEventDetails.

        Month specified in picture timing

        :return: The month of this LiveEncodingStatsEventDetails.
        :rtype: int
        """
        return self._month

    @month.setter
    def month(self, month):
        # type: (int) -> None
        """Sets the month of this LiveEncodingStatsEventDetails.

        Month specified in picture timing

        :param month: The month of this LiveEncodingStatsEventDetails.
        :type: int
        """

        if month is not None:
            if not isinstance(month, int):
                raise TypeError("Invalid type for `month`, type has to be `int`")

        self._month = month

    @property
    def day(self):
        # type: () -> int
        """Gets the day of this LiveEncodingStatsEventDetails.

        Day specified in picture timing

        :return: The day of this LiveEncodingStatsEventDetails.
        :rtype: int
        """
        return self._day

    @day.setter
    def day(self, day):
        # type: (int) -> None
        """Sets the day of this LiveEncodingStatsEventDetails.

        Day specified in picture timing

        :param day: The day of this LiveEncodingStatsEventDetails.
        :type: int
        """

        if day is not None:
            if not isinstance(day, int):
                raise TypeError("Invalid type for `day`, type has to be `int`")

        self._day = day

    @property
    def hours(self):
        # type: () -> int
        """Gets the hours of this LiveEncodingStatsEventDetails.

        Hours specified in picture timing

        :return: The hours of this LiveEncodingStatsEventDetails.
        :rtype: int
        """
        return self._hours

    @hours.setter
    def hours(self, hours):
        # type: (int) -> None
        """Sets the hours of this LiveEncodingStatsEventDetails.

        Hours specified in picture timing

        :param hours: The hours of this LiveEncodingStatsEventDetails.
        :type: int
        """

        if hours is not None:
            if not isinstance(hours, int):
                raise TypeError("Invalid type for `hours`, type has to be `int`")

        self._hours = hours

    @property
    def minutes(self):
        # type: () -> int
        """Gets the minutes of this LiveEncodingStatsEventDetails.

        Minutes specified in picture timing

        :return: The minutes of this LiveEncodingStatsEventDetails.
        :rtype: int
        """
        return self._minutes

    @minutes.setter
    def minutes(self, minutes):
        # type: (int) -> None
        """Sets the minutes of this LiveEncodingStatsEventDetails.

        Minutes specified in picture timing

        :param minutes: The minutes of this LiveEncodingStatsEventDetails.
        :type: int
        """

        if minutes is not None:
            if not isinstance(minutes, int):
                raise TypeError("Invalid type for `minutes`, type has to be `int`")

        self._minutes = minutes

    @property
    def seconds(self):
        # type: () -> int
        """Gets the seconds of this LiveEncodingStatsEventDetails.

        Seconds specified in picture timing

        :return: The seconds of this LiveEncodingStatsEventDetails.
        :rtype: int
        """
        return self._seconds

    @seconds.setter
    def seconds(self, seconds):
        # type: (int) -> None
        """Sets the seconds of this LiveEncodingStatsEventDetails.

        Seconds specified in picture timing

        :param seconds: The seconds of this LiveEncodingStatsEventDetails.
        :type: int
        """

        if seconds is not None:
            if not isinstance(seconds, int):
                raise TypeError("Invalid type for `seconds`, type has to be `int`")

        self._seconds = seconds

    @property
    def micro_seconds(self):
        # type: () -> int
        """Gets the micro_seconds of this LiveEncodingStatsEventDetails.

        Microseconds specified in picture timing

        :return: The micro_seconds of this LiveEncodingStatsEventDetails.
        :rtype: int
        """
        return self._micro_seconds

    @micro_seconds.setter
    def micro_seconds(self, micro_seconds):
        # type: (int) -> None
        """Sets the micro_seconds of this LiveEncodingStatsEventDetails.

        Microseconds specified in picture timing

        :param micro_seconds: The micro_seconds of this LiveEncodingStatsEventDetails.
        :type: int
        """

        if micro_seconds is not None:
            if not isinstance(micro_seconds, int):
                raise TypeError("Invalid type for `micro_seconds`, type has to be `int`")

        self._micro_seconds = micro_seconds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveEncodingStatsEventDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class EsamMediaPoint(object):
    @poscheck_model
    def __init__(self,
                 match_time=None,
                 signals=None,
                 conditions=None):
        # type: (datetime, list[EsamSignal], list[EsamCondition]) -> None

        self._match_time = None
        self._signals = list()
        self._conditions = list()
        self.discriminator = None

        if match_time is not None:
            self.match_time = match_time
        if signals is not None:
            self.signals = signals
        if conditions is not None:
            self.conditions = conditions

    @property
    def openapi_types(self):
        types = {
            'match_time': 'datetime',
            'signals': 'list[EsamSignal]',
            'conditions': 'list[EsamCondition]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'match_time': 'matchTime',
            'signals': 'signals',
            'conditions': 'conditions'
        }
        return attributes

    @property
    def match_time(self):
        # type: () -> datetime
        """Gets the match_time of this EsamMediaPoint.

        ISO 8601 date-time specifying when the signal should be matched and inserted into the live stream

        :return: The match_time of this EsamMediaPoint.
        :rtype: datetime
        """
        return self._match_time

    @match_time.setter
    def match_time(self, match_time):
        # type: (datetime) -> None
        """Sets the match_time of this EsamMediaPoint.

        ISO 8601 date-time specifying when the signal should be matched and inserted into the live stream

        :param match_time: The match_time of this EsamMediaPoint.
        :type: datetime
        """

        if match_time is not None:
            if not isinstance(match_time, datetime):
                raise TypeError("Invalid type for `match_time`, type has to be `datetime`")

        self._match_time = match_time

    @property
    def signals(self):
        # type: () -> list[EsamSignal]
        """Gets the signals of this EsamMediaPoint.

        Array of ESAM signals containing SCTE-35 binary data. At least one signal is required (required)

        :return: The signals of this EsamMediaPoint.
        :rtype: list[EsamSignal]
        """
        return self._signals

    @signals.setter
    def signals(self, signals):
        # type: (list) -> None
        """Sets the signals of this EsamMediaPoint.

        Array of ESAM signals containing SCTE-35 binary data. At least one signal is required (required)

        :param signals: The signals of this EsamMediaPoint.
        :type: list[EsamSignal]
        """

        if signals is not None:
            if not isinstance(signals, list):
                raise TypeError("Invalid type for `signals`, type has to be `list[EsamSignal]`")

        self._signals = signals

    @property
    def conditions(self):
        # type: () -> list[EsamCondition]
        """Gets the conditions of this EsamMediaPoint.

        Optional array of ESAM conditions with timing offsets and directional markers (OUT/IN) for signaling content boundaries

        :return: The conditions of this EsamMediaPoint.
        :rtype: list[EsamCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        # type: (list) -> None
        """Sets the conditions of this EsamMediaPoint.

        Optional array of ESAM conditions with timing offsets and directional markers (OUT/IN) for signaling content boundaries

        :param conditions: The conditions of this EsamMediaPoint.
        :type: list[EsamCondition]
        """

        if conditions is not None:
            if not isinstance(conditions, list):
                raise TypeError("Invalid type for `conditions`, type has to be `list[EsamCondition]`")

        self._conditions = conditions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EsamMediaPoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class EsamDirection(Enum):
    OUT = "OUT"
    IN = "IN"
    BOTH = "BOTH"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class RtmpUserIngestInfo(object):
    @poscheck_model
    def __init__(self,
                 address=None,
                 app=None,
                 stream_key=None,
                 flash_version=None,
                 client_id=None,
                 event_type=None):
        # type: (string_types, string_types, string_types, string_types, string_types, string_types) -> None

        self._address = None
        self._app = None
        self._stream_key = None
        self._flash_version = None
        self._client_id = None
        self._event_type = None
        self.discriminator = None

        if address is not None:
            self.address = address
        if app is not None:
            self.app = app
        if stream_key is not None:
            self.stream_key = stream_key
        if flash_version is not None:
            self.flash_version = flash_version
        if client_id is not None:
            self.client_id = client_id
        if event_type is not None:
            self.event_type = event_type

    @property
    def openapi_types(self):
        types = {
            'address': 'string_types',
            'app': 'string_types',
            'stream_key': 'string_types',
            'flash_version': 'string_types',
            'client_id': 'string_types',
            'event_type': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'address': 'address',
            'app': 'app',
            'stream_key': 'streamKey',
            'flash_version': 'flashVersion',
            'client_id': 'clientId',
            'event_type': 'eventType'
        }
        return attributes

    @property
    def address(self):
        # type: () -> string_types
        """Gets the address of this RtmpUserIngestInfo.

        Client public IP address.

        :return: The address of this RtmpUserIngestInfo.
        :rtype: string_types
        """
        return self._address

    @address.setter
    def address(self, address):
        # type: (string_types) -> None
        """Sets the address of this RtmpUserIngestInfo.

        Client public IP address.

        :param address: The address of this RtmpUserIngestInfo.
        :type: string_types
        """

        if address is not None:
            if not isinstance(address, string_types):
                raise TypeError("Invalid type for `address`, type has to be `string_types`")

        self._address = address

    @property
    def app(self):
        # type: () -> string_types
        """Gets the app of this RtmpUserIngestInfo.

        RTMP application name.

        :return: The app of this RtmpUserIngestInfo.
        :rtype: string_types
        """
        return self._app

    @app.setter
    def app(self, app):
        # type: (string_types) -> None
        """Sets the app of this RtmpUserIngestInfo.

        RTMP application name.

        :param app: The app of this RtmpUserIngestInfo.
        :type: string_types
        """

        if app is not None:
            if not isinstance(app, string_types):
                raise TypeError("Invalid type for `app`, type has to be `string_types`")

        self._app = app

    @property
    def stream_key(self):
        # type: () -> string_types
        """Gets the stream_key of this RtmpUserIngestInfo.

        Client stream key.

        :return: The stream_key of this RtmpUserIngestInfo.
        :rtype: string_types
        """
        return self._stream_key

    @stream_key.setter
    def stream_key(self, stream_key):
        # type: (string_types) -> None
        """Sets the stream_key of this RtmpUserIngestInfo.

        Client stream key.

        :param stream_key: The stream_key of this RtmpUserIngestInfo.
        :type: string_types
        """

        if stream_key is not None:
            if not isinstance(stream_key, string_types):
                raise TypeError("Invalid type for `stream_key`, type has to be `string_types`")

        self._stream_key = stream_key

    @property
    def flash_version(self):
        # type: () -> string_types
        """Gets the flash_version of this RtmpUserIngestInfo.

        Flash version string / encoder identity.

        :return: The flash_version of this RtmpUserIngestInfo.
        :rtype: string_types
        """
        return self._flash_version

    @flash_version.setter
    def flash_version(self, flash_version):
        # type: (string_types) -> None
        """Sets the flash_version of this RtmpUserIngestInfo.

        Flash version string / encoder identity.

        :param flash_version: The flash_version of this RtmpUserIngestInfo.
        :type: string_types
        """

        if flash_version is not None:
            if not isinstance(flash_version, string_types):
                raise TypeError("Invalid type for `flash_version`, type has to be `string_types`")

        self._flash_version = flash_version

    @property
    def client_id(self):
        # type: () -> string_types
        """Gets the client_id of this RtmpUserIngestInfo.

        Session/client connection ID.

        :return: The client_id of this RtmpUserIngestInfo.
        :rtype: string_types
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        # type: (string_types) -> None
        """Sets the client_id of this RtmpUserIngestInfo.

        Session/client connection ID.

        :param client_id: The client_id of this RtmpUserIngestInfo.
        :type: string_types
        """

        if client_id is not None:
            if not isinstance(client_id, string_types):
                raise TypeError("Invalid type for `client_id`, type has to be `string_types`")

        self._client_id = client_id

    @property
    def event_type(self):
        # type: () -> string_types
        """Gets the event_type of this RtmpUserIngestInfo.

        Server action.

        :return: The event_type of this RtmpUserIngestInfo.
        :rtype: string_types
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        # type: (string_types) -> None
        """Sets the event_type of this RtmpUserIngestInfo.

        Server action.

        :param event_type: The event_type of this RtmpUserIngestInfo.
        :type: string_types
        """

        if event_type is not None:
            if not isinstance(event_type, string_types):
                raise TypeError("Invalid type for `event_type`, type has to be `string_types`")

        self._event_type = event_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RtmpUserIngestInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.scene_dynamics import SceneDynamics
import pprint
import six


class Content(object):
    @poscheck_model
    def __init__(self,
                 characters=None,
                 objects=None,
                 settings=None,
                 dynamics=None):
        # type: (list[Character], list[SceneObject], list[Setting], SceneDynamics) -> None

        self._characters = list()
        self._objects = list()
        self._settings = list()
        self._dynamics = None
        self.discriminator = None

        if characters is not None:
            self.characters = characters
        if objects is not None:
            self.objects = objects
        if settings is not None:
            self.settings = settings
        if dynamics is not None:
            self.dynamics = dynamics

    @property
    def openapi_types(self):
        types = {
            'characters': 'list[Character]',
            'objects': 'list[SceneObject]',
            'settings': 'list[Setting]',
            'dynamics': 'SceneDynamics'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'characters': 'characters',
            'objects': 'objects',
            'settings': 'settings',
            'dynamics': 'dynamics'
        }
        return attributes

    @property
    def characters(self):
        # type: () -> list[Character]
        """Gets the characters of this Content.


        :return: The characters of this Content.
        :rtype: list[Character]
        """
        return self._characters

    @characters.setter
    def characters(self, characters):
        # type: (list) -> None
        """Sets the characters of this Content.


        :param characters: The characters of this Content.
        :type: list[Character]
        """

        if characters is not None:
            if not isinstance(characters, list):
                raise TypeError("Invalid type for `characters`, type has to be `list[Character]`")

        self._characters = characters

    @property
    def objects(self):
        # type: () -> list[SceneObject]
        """Gets the objects of this Content.


        :return: The objects of this Content.
        :rtype: list[SceneObject]
        """
        return self._objects

    @objects.setter
    def objects(self, objects):
        # type: (list) -> None
        """Sets the objects of this Content.


        :param objects: The objects of this Content.
        :type: list[SceneObject]
        """

        if objects is not None:
            if not isinstance(objects, list):
                raise TypeError("Invalid type for `objects`, type has to be `list[SceneObject]`")

        self._objects = objects

    @property
    def settings(self):
        # type: () -> list[Setting]
        """Gets the settings of this Content.


        :return: The settings of this Content.
        :rtype: list[Setting]
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        # type: (list) -> None
        """Sets the settings of this Content.


        :param settings: The settings of this Content.
        :type: list[Setting]
        """

        if settings is not None:
            if not isinstance(settings, list):
                raise TypeError("Invalid type for `settings`, type has to be `list[Setting]`")

        self._settings = settings

    @property
    def dynamics(self):
        # type: () -> SceneDynamics
        """Gets the dynamics of this Content.


        :return: The dynamics of this Content.
        :rtype: SceneDynamics
        """
        return self._dynamics

    @dynamics.setter
    def dynamics(self, dynamics):
        # type: (SceneDynamics) -> None
        """Sets the dynamics of this Content.


        :param dynamics: The dynamics of this Content.
        :type: SceneDynamics
        """

        if dynamics is not None:
            if not isinstance(dynamics, SceneDynamics):
                raise TypeError("Invalid type for `dynamics`, type has to be `SceneDynamics`")

        self._dynamics = dynamics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Content):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.live.encodings.dns_mappings.dns_mappings_api import DnsMappingsApi
from bitmovin_api_sdk.encoding.live.encodings.dns_mappings.dns_mapping_response_list_query_params import DnsMappingResponseListQueryParams



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.live_encoding_heartbeat_ingest import LiveEncodingHeartbeatIngest
import pprint
import six


class LiveEncodingHeartbeat(object):
    @poscheck_model
    def __init__(self,
                 timestamp=None,
                 ingest=None,
                 events=None):
        # type: (datetime, LiveEncodingHeartbeatIngest, list[LiveEncodingHeartbeatEvent]) -> None

        self._timestamp = None
        self._ingest = None
        self._events = list()
        self.discriminator = None

        if timestamp is not None:
            self.timestamp = timestamp
        if ingest is not None:
            self.ingest = ingest
        if events is not None:
            self.events = events

    @property
    def openapi_types(self):
        types = {
            'timestamp': 'datetime',
            'ingest': 'LiveEncodingHeartbeatIngest',
            'events': 'list[LiveEncodingHeartbeatEvent]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'timestamp': 'timestamp',
            'ingest': 'ingest',
            'events': 'events'
        }
        return attributes

    @property
    def timestamp(self):
        # type: () -> datetime
        """Gets the timestamp of this LiveEncodingHeartbeat.

        timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :return: The timestamp of this LiveEncodingHeartbeat.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        # type: (datetime) -> None
        """Sets the timestamp of this LiveEncodingHeartbeat.

        timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :param timestamp: The timestamp of this LiveEncodingHeartbeat.
        :type: datetime
        """

        if timestamp is not None:
            if not isinstance(timestamp, datetime):
                raise TypeError("Invalid type for `timestamp`, type has to be `datetime`")

        self._timestamp = timestamp

    @property
    def ingest(self):
        # type: () -> LiveEncodingHeartbeatIngest
        """Gets the ingest of this LiveEncodingHeartbeat.

        Information about the live ingestion status 

        :return: The ingest of this LiveEncodingHeartbeat.
        :rtype: LiveEncodingHeartbeatIngest
        """
        return self._ingest

    @ingest.setter
    def ingest(self, ingest):
        # type: (LiveEncodingHeartbeatIngest) -> None
        """Sets the ingest of this LiveEncodingHeartbeat.

        Information about the live ingestion status 

        :param ingest: The ingest of this LiveEncodingHeartbeat.
        :type: LiveEncodingHeartbeatIngest
        """

        if ingest is not None:
            if not isinstance(ingest, LiveEncodingHeartbeatIngest):
                raise TypeError("Invalid type for `ingest`, type has to be `LiveEncodingHeartbeatIngest`")

        self._ingest = ingest

    @property
    def events(self):
        # type: () -> list[LiveEncodingHeartbeatEvent]
        """Gets the events of this LiveEncodingHeartbeat.

        Live encoding heartbeat events 

        :return: The events of this LiveEncodingHeartbeat.
        :rtype: list[LiveEncodingHeartbeatEvent]
        """
        return self._events

    @events.setter
    def events(self, events):
        # type: (list) -> None
        """Sets the events of this LiveEncodingHeartbeat.

        Live encoding heartbeat events 

        :param events: The events of this LiveEncodingHeartbeat.
        :type: list[LiveEncodingHeartbeatEvent]
        """

        if events is not None:
            if not isinstance(events, list):
                raise TypeError("Invalid type for `events`, type has to be `list[LiveEncodingHeartbeatEvent]`")

        self._events = events

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveEncodingHeartbeat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
